@@ -20,6 +20,7 @@
 """
 
 import json
+import sys
 
 import pytest
 
@@ -168,6 +169,8 @@ class TestChannel(object):
         new = self.TEST_CLASS('test', model=arg)
         assert new.model == model
 
+    @pytest.mark.xfail(sys.version_info < (3, 4),
+                       reason="enum34 error messages don't match python34")
     @pytest.mark.parametrize('arg, type_, ndstype', [
         (None, None, None),
         ('m-trend', 'm-trend', 16),
@@ -178,7 +181,7 @@ class TestChannel(object):
         if type_ == 'RAISE':  # check invalid raises correct exception
             with pytest.raises(ValueError) as exc:
                 c = self.TEST_CLASS('', type=arg)
-            assert str(exc.value) == '%s is not a valid Nds2ChannelType' % arg
+            assert str(exc.value) == '%r is not a valid Nds2ChannelType' % arg
         else:
             c = self.TEST_CLASS('', type=arg)
             assert getattr(c, 'type') == type_
@@ -186,8 +189,10 @@ class TestChannel(object):
 
     @pytest.mark.parametrize('arg, dtype', [
         (None, None),
+        (16, numpy.dtype('float64')),
         (float, numpy.dtype('float64')),
         ('float', numpy.dtype('float64')),
+        ('float64', numpy.dtype('float64')),
         ('u4', numpy.dtype('uint32')),
     ])
     def test_dtype(self, arg, dtype):
