@@ -29,7 +29,6 @@ from astropy.io import registry as io_registry
 
 from ..types import Series
 from ..detector import Channel
-from ._fdcommon import fdfilter
 
 
 __author__ = "Duncan Macleod <duncan.macleod@ligo.org"
@@ -90,7 +89,7 @@ class FrequencySeries(Series):
        ~FrequencySeries.zpk
     """
     _default_xunit = units.Unit('Hz')
-    _print_slots = ['f0', 'df', 'epoch', 'name', 'channel', '_frequencies']
+    _print_slots = ['f0', 'df', 'epoch', 'name', 'channel']
 
     def __new__(cls, data, unit=None, f0=None, df=None, frequencies=None,
                 name=None, epoch=None, channel=None, **kwargs):
@@ -158,6 +157,11 @@ class FrequencySeries(Series):
         **kwargs
             Other keywords are (in general) specific to the given ``format``.
 
+        Raises
+        ------
+        IndexError
+            if ``source`` is an empty list
+
         Notes
         -----"""
         return io_registry.read(cls, source, *args, **kwargs)
@@ -208,10 +212,9 @@ class FrequencySeries(Series):
         out : :class:`~gwpy.timeseries.TimeSeries`
             the normalised, real-valued `TimeSeries`.
 
-        See Also
+        See also
         --------
-        :mod:`scipy.fftpack` for the definition of the DFT and conventions
-        used.
+        numpy.fft.irfft : The inverse (real) FFT function
 
         Notes
         -----
@@ -254,7 +257,7 @@ class FrequencySeries(Series):
         spectrum : `FrequencySeries`
             the frequency-domain filtered version of the input data
 
-        See Also
+        See also
         --------
         FrequencySeries.filter
             for details on how a digital ZPK-format filter is applied
@@ -282,7 +285,7 @@ class FrequencySeries(Series):
         out : `FrequencySeries`
             the interpolated version of the input `FrequencySeries`
 
-        See Also
+        See also
         --------
         numpy.interp
             for the underlying 1-D linear interpolation scheme
@@ -331,6 +334,7 @@ class FrequencySeries(Series):
         ValueError
             if ``filt`` arguments cannot be interpreted properly
         """
+        from ._fdcommon import fdfilter
         return fdfilter(self, *filt, **kwargs)
 
     def filterba(self, *args, **kwargs):
