@@ -40,17 +40,15 @@ SEGMENTS = SegmentList(map(Segment, [
     (1, 2),
     (4, 5),
 ]))
+CACHE = [os.path.join('tmp', 'A-B-%d-%d.tmp' % (seg[0], seg[1] - seg[0])) for
+         seg in SEGMENTS]
 
 
 # -- fixtures -----------------------------------------------------------------
 
 @pytest.fixture
 def cache():
-    cache = []
-    for seg in SEGMENTS:
-        d = seg[1] - seg[0]
-        cache.append(os.path.join('tmp', 'A-B-%d-%d.tmp' % (seg[0], d)))
-    return cache
+    return list(CACHE)
 
 
 @pytest.fixture
@@ -60,30 +58,59 @@ def segments():
 
 # -- tests --------------------------------------------------------------------
 
-@skip_missing_dependency('lal.utils')
-def test_read_write_cache(cache, tmpfile):
-    from lal.utils import CacheEntry
-    lcache = list(map(CacheEntry.from_T050017, cache))
+@pytest.mark.parametrize("format, entry1", [
+    (None, CACHE[0]),
+    pytest.param(
+        "lal",
+        "A B {0[0]} {1} {2}".format(SEGMENTS[0], abs(SEGMENTS[0]), CACHE[0]),
+        id="lal"),
+    pytest.param(
+        "ffl",
+        "{0} {1[0]} {2} 0 0".format(CACHE[0], SEGMENTS[0], abs(SEGMENTS[0])),
+        id="ffl"),
+])
+def test_read_write_cache(cache, tmpfile, format, entry1):
+    # write cache using filename
+    io_cache.write_cache(cache, tmpfile, format=format)
 
-    with open(tmpfile, 'w') as f:
-        io_cache.write_cache(lcache, f)
+    # check that first line is proper LAL format
+    with open(tmpfile, "r") as tmp:
+        assert tmp.readline().strip() == entry1
 
-    # read from fileobj
-    with open(tmpfile) as f:
-        c2 = io_cache.read_cache(tmpfile)
-    assert cache == c2
+    # now read it back ans check we get the same answer
+    assert io_cache.read_cache(tmpfile) == cache
 
-    # write with file name
-    io_cache.write_cache(lcache, tmpfile)
-
-    # read from file name
-    c3 = io_cache.read_cache(tmpfile)
-    assert cache == c3
+    # check read/write with a file object
+    with open(tmpfile, "w") as tmp:
+        io_cache.write_cache(cache, tmp, format=format)
+    with open(tmpfile, "r") as tmp:
+        assert io_cache.read_cache(tmp) == cache
 
     # check sieving and sorting works
-    c4 = io_cache.read_cache(tmpfile, sort=lambda e: -e.segment[0],
-                             segment=Segment(0, 2))
-    assert c4 == cache[1::-1]
+    assert io_cache.read_cache(
+        tmpfile,
+        sort=lambda e: -io_cache.filename_metadata(e)[2][0],
+        segment=Segment(0, 2),
+    ) == cache[1::-1]
+
+
+@skip_missing_dependency('lal.utils')
+def test_write_cache_cacheentry(cache, tmpfile):
+    from lal.utils import CacheEntry
+    lcache = list(map(CacheEntry.from_T050017, cache))
+    with open(tmpfile, 'w') as f:
+        io_cache.write_cache(lcache, f, format=None)
+
+    # check first line looks like a LAL-format cache entry
+    with open(tmpfile, "r") as tmp:
+        assert tmp.readline().strip() == "A B {0[0]} {1} {2}".format(
+            SEGMENTS[0],
+            abs(SEGMENTS[0]),
+            CACHE[0],
+        )
+
+    # read from file name
+    assert io_cache.read_cache(tmpfile) == cache
 
 
 @pytest.mark.parametrize('input_, result', [
@@ -160,6 +187,21 @@ def test_cache_segments(cache, segments):
     assert sl == segments
 
 
+@pytest.mark.parametrize("path, metadata", [
+    ("A-B-0-1.txt", ('A', 'B', Segment(0, 1))),
+    ("/path/to/A-B-0.456-1.345.txt.gz", ("A", "B", Segment(0.456, 1.801))),
+])
+def test_filename_metadata(path, metadata):
+    """Test :func:`gwpy.io.cache.filename_metadata`
+    """
+    assert io_cache.filename_metadata(path) == metadata
+
+
+def test_filename_metadata_error():
+    with pytest.raises(ValueError):
+        io_cache.filename_metadata("A-B-0-4xml.gz")
+
+
 def test_file_segment():
     """Test :func:`gwpy.io.cache.file_segment`
     """
