@@ -19,6 +19,7 @@
 """Extension of `~matplotlib.axes.Axes` for gwpy
 """
 
+import warnings
 from functools import wraps
 from math import log
 from numbers import Number
@@ -30,7 +31,7 @@ from astropy.time import Time
 from matplotlib import (__version__ as mpl_version, rcParams)
 from matplotlib.artist import allow_rasterization
 from matplotlib.axes import Axes as _Axes
-from matplotlib.cbook import iterable
+from matplotlib.lines import Line2D
 from matplotlib.collections import PolyCollection
 from matplotlib.projections import register_projection
 try:
@@ -40,9 +41,9 @@ except ImportError:  # matplotlib-1.x
 
 from . import (Plot, colorbar as gcbar)
 from .colors import format_norm
-from ..time import (LIGOTimeGPS, to_gps)
-from ..types import (Series, Array2D)
 from .gps import GPS_SCALES
+from .legend import HandlerLine2D
+from ..time import (LIGOTimeGPS, to_gps)
 
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
 
@@ -65,7 +66,7 @@ def xlim_as_gps(func):
     """
     @wraps(func)
     def wrapped_func(self, left=None, right=None, **kw):
-        if right is None and iterable(left):
+        if right is None and numpy.iterable(left):
             left, right = left
         kw['left'] = left
         kw['right'] = right
@@ -138,12 +139,12 @@ class Axes(_Axes):
     def _fmt_xdata(self, x):
         if self.get_xscale() in GPS_SCALES:
             return str(LIGOTimeGPS(x))
-        raise TypeError  # fall back to default
+        return self.xaxis.get_major_formatter().format_data_short(x)
 
     def _fmt_ydata(self, y):
         if self.get_yscale() in GPS_SCALES:
             return str(LIGOTimeGPS(y))
-        raise TypeError  # fall back to default
+        return self.yaxis.get_major_formatter().format_data_short(y)
 
     set_xlim = xlim_as_gps(_Axes.set_xlim)
 
@@ -224,12 +225,12 @@ class Axes(_Axes):
             All arguments and keywords are passed to the inherited
             :meth:`~matplotlib.axes.Axes.imshow` method.
 
-        See Also
+        See also
         --------
         matplotlib.axes.Axes.imshow
             for details of the image rendering
         """
-        if isinstance(array, Array2D):
+        if hasattr(array, "yspan"):  # Array2D
             return self._imshow_array2d(array, *args, **kwargs)
 
         image = super(Axes, self).imshow(array, *args, **kwargs)
@@ -271,11 +272,11 @@ class Axes(_Axes):
         Unlike the upstream :meth:`matplotlib.axes.Axes.pcolormesh`,
         this method respects the current grid settings.
 
-        See Also
+        See also
         --------
         matplotlib.axes.Axes.pcolormesh
         """
-        if len(args) == 1 and isinstance(args[0], Array2D):
+        if len(args) == 1 and hasattr(args[0], "yindex"):  # Array2D
             return self._pcolormesh_array2d(*args, **kwargs)
         return super(Axes, self).pcolormesh(*args, **kwargs)
 
@@ -297,7 +298,7 @@ class Axes(_Axes):
 
         # calculate log-spaced bins on-the-fly
         if (kwargs.pop('logbins', False) and
-                not iterable(kwargs.get('bins', None))):
+                not numpy.iterable(kwargs.get('bins', None))):
             nbins = kwargs.get('bins', None) or rcParams.get('hist.bins', 30)
             # get range
             hrange = kwargs.pop('range', None)
@@ -367,7 +368,7 @@ class Axes(_Axes):
             - `~matplotlib.lines.Line2D` for ``upper``, if given
             - `~matplitlib.collections.PolyCollection` for shading
 
-        See Also
+        See also
         --------
         matplotlib.axes.Axes.plot
             for a full description of acceptable ``*args`` and ``**kwargs``
@@ -495,21 +496,34 @@ class Axes(_Axes):
     # -- overloaded auxiliary methods -----------
 
     def legend(self, *args, **kwargs):
-        alpha = kwargs.pop("alpha", 0.8)
-        linewidth = kwargs.pop("linewidth", 8)
+        # handle deprecated keywords
+        linewidth = kwargs.pop("linewidth", None)
+        if linewidth:
+            warnings.warn(
+                "the linewidth keyword to gwpy.plot.Axes.legend has been "
+                "deprecated and will be removed in a future release; "
+                "please update your code to use a custom legend handler, "
+                "e.g. gwpy.plot.legend.HandlerLine2D.",
+                DeprecationWarning,
+            )
+        alpha = kwargs.pop("alpha", None)
+        if alpha:
+            if mpl_version >= "1.3.0":  # matplotlib >= 1.3.0
+                kwargs.setdefault("framealpha", alpha)
+            warnings.warn(
+                "the alpha keyword to gwpy.plot.Axes.legend has been "
+                "deprecated and will be removed in a future release; "
+                "use framealpha instead.",
+                DeprecationWarning,
+            )
 
-        # make legend
-        legend = super(Axes, self).legend(*args, **kwargs)
+        # build custom handler
+        handler_map = kwargs.setdefault("handler_map", dict())
+        if isinstance(handler_map, dict):
+            handler_map.setdefault(Line2D, HandlerLine2D(linewidth or 6))
 
-        # update alpha and linewidth for legend elements
-        if legend is not None:
-            lframe = legend.get_frame()
-            lframe.set_alpha(alpha)
-            lframe.set_linewidth(rcParams['axes.linewidth'])
-            for line in legend.get_lines():
-                line.set_linewidth(linewidth)
-
-        return legend
+        # create legend
+        return super(Axes, self).legend(*args, **kwargs)
 
     legend.__doc__ = _Axes.legend.__doc__
 
@@ -537,7 +551,7 @@ class Axes(_Axes):
         cbar : `~matplotlib.colorbar.Colorbar`
             the newly added `Colorbar`
 
-        See Also
+        See also
         --------
         Plot.colorbar
         """
@@ -568,14 +582,15 @@ register_projection(Axes)
 class PlotArgsProcessor(_process_plot_var_args):
     """This class controls how ax.plot() works
     """
-    def _grab_next_args(self, *args, **kwargs):
+    def __call__(self, *args, **kwargs):
         """Find `Series` data in `plot()` args and unwrap
         """
+        newargs = []
         while args:
             # strip first argument
             this, args = args[:1], args[1:]
             # it its a 1-D Series, then parse it as (xindex, value)
-            if isinstance(this[0], Series) and this[0].ndim == 1:
+            if hasattr(this[0], "xindex") and this[0].ndim == 1:
                 this = (this[0].xindex.value, this[0].value)
             # otherwise treat as normal (must be a second argument)
             else:
@@ -585,6 +600,6 @@ class PlotArgsProcessor(_process_plot_var_args):
             if args and isinstance(args[0], str):
                 this += args[0],
                 args = args[1:]
-            # use yield from with python3
-            for item in self._plot_args(this, kwargs):
-                yield item
+            newargs.extend(this)
+
+        return super(PlotArgsProcessor, self).__call__(*newargs, **kwargs)
