@@ -22,7 +22,10 @@
 import itertools
 import importlib
 import warnings
-from collections import (KeysView, ValuesView)
+try:
+    from collections.abc import (KeysView, ValuesView)
+except ImportError:  # python < 3.3
+    from collections import (KeysView, ValuesView)
 
 from six.moves import zip_longest
 
@@ -365,7 +368,7 @@ class Plot(figure.Figure):
         cbar : `~matplotlib.colorbar.Colorbar`
             the newly added `Colorbar`
 
-        See Also
+        See also
         --------
         matplotlib.figure.Figure.colorbar
         matplotlib.colorbar.Colorbar
