@@ -21,7 +21,6 @@
 
 from matplotlib import (rcParams, rc_params, RcParams,
                         __version__ as mpl_version)
-from matplotlib.figure import SubplotParams
 
 from . import tex
 from ..utils.env import bool_env
@@ -29,6 +28,12 @@ from ..utils.env import bool_env
 # record matplotlib's original rcParams
 MPL_RCPARAMS = rc_params()
 
+# record the LaTeX preamble
+try:
+    PREAMBLE = rcParams.get('text.latex.preamble', []) + tex.MACROS
+except TypeError:
+    PREAMBLE = rcParams.get('text.latex.preamble', '') + '\n'.join(tex.MACROS)
+
 __author__ = "Duncan Macleod <duncan.macleod@ligo.org>"
 
 # -- custom rc ----------------------------------------------------------------
@@ -75,8 +80,7 @@ except KeyError:  # matplotlib < 1.5
 GWPY_TEX_RCPARAMS = RcParams(**{
     # use latex styling
     'text.usetex': True,
-    'text.latex.preamble': (
-        rcParams.get('text.latex.preamble', []) + tex.MACROS),
+    'text.latex.preamble': PREAMBLE,
     # use bigger font for labels (since the font is good)
     'font.family': ['serif'],
     'font.size': 16,
@@ -163,6 +167,8 @@ def get_subplot_params(figsize):
     params : `~matplotlib.figure.SubplotParams`
         formatted set of subplot parameters
     """
+    from matplotlib.figure import SubplotParams
+
     width, height, = figsize
     try:
         left, right = SUBPLOT_WIDTH[width]
