@@ -387,7 +387,7 @@ class DataQualityFlag(object):
             ``$DEFAULT_SEGMENT_SERVER`` environment variable, or
             ``'https://segments.ligo.org'``
 
-        See Also
+        See also
         --------
         DataQualityFlag.query_segdb
         DataQualityFlag.query_dqsegdb
@@ -494,7 +494,7 @@ class DataQualityFlag(object):
         for start, end in qsegs:
             # handle infinities
             if float(end) == +inf:
-                end = to_gps('now').seconds
+                end = int(to_gps('now'))
 
             # query
             try:
@@ -552,7 +552,7 @@ class DataQualityFlag(object):
         --------
         >>> from gwpy.segments import DataQualityFlag
         >>> print(DataQualityFlag.fetch_open_data('H1_DATA', 'Jan 1 2010',
-        ...                                       'Jan 2 2010'))"
+        ...                                       'Jan 2 2010'))
         <DataQualityFlag('H1:DATA',
                          known=[[946339215 ... 946425615)],
                          active=[[946340946 ... 946351800)
@@ -613,6 +613,11 @@ class DataQualityFlag(object):
             formatted `DataQualityFlag` containing the active and known
             segments read from file.
 
+        Raises
+        ------
+        IndexError
+            if ``source`` is an empty list
+
         Notes
         -----"""
         if 'flag' in kwargs:  # pragma: no cover
@@ -640,7 +645,7 @@ class DataQualityFlag(object):
 
         Parameters
         ----------
-        veto : :class:`~glue.ligolw.lsctables.VetoDef`
+        veto : :class:`~ligo.lw.lsctables.VetoDef`
             veto definition to convert from
         """
         name = '%s:%s' % (veto.ifo, veto.name)
@@ -890,7 +895,7 @@ class DataQualityFlag(object):
         figure : `~matplotlib.figure.Figure`
             the newly created figure, with populated Axes.
 
-        See Also
+        See also
         --------
         matplotlib.pyplot.figure
             for documentation of keyword arguments used to create the
@@ -936,6 +941,8 @@ class DataQualityFlag(object):
             If the input ``name`` cannot be parsed into
             {ifo}:{tag}:{version} format.
         """
+        if isinstance(name, bytes):
+            name = name.decode('utf-8')
         if name is None:
             self.ifo = None
             self.tag = None
@@ -1076,7 +1083,7 @@ class DataQualityDict(OrderedDict):
             ``$DEFAULT_SEGMENT_SERVER`` environment variable, or
             ``'https://segments.ligo.org'``
 
-        See Also
+        See also
         --------
         DataQualityDict.query_segdb
         DataQualityDict.query_dqsegdb
@@ -1145,7 +1152,7 @@ class DataQualityDict(OrderedDict):
                 vers = dqflag.version
             for gpsstart, gpsend in qsegs:
                 if float(gpsend) == +inf:
-                    gpsend = to_gps('now').seconds
+                    gpsend = int(to_gps('now'))
                 gpsstart = float(gpsstart)
                 if not gpsstart.is_integer():
                     raise ValueError("Segment database queries can only"
@@ -1406,13 +1413,13 @@ class DataQualityDict(OrderedDict):
 
         Parameters
         ----------
-        segmentdeftable : :class:`~glue.ligolw.lsctables.SegmentDefTable`
+        segmentdeftable : :class:`~ligo.lw.lsctables.SegmentDefTable`
             the ``segment_definer`` table to read
 
-        segmentsumtable : :class:`~glue.ligolw.lsctables.SegmentSumTable`
+        segmentsumtable : :class:`~ligo.lw.lsctables.SegmentSumTable`
             the ``segment_summary`` table to read
 
-        segmenttable : :class:`~glue.ligolw.lsctables.SegmentTable`
+        segmenttable : :class:`~ligo.lw.lsctables.SegmentTable`
             the ``segment`` table to read
 
         names : `list` of `str`, optional
@@ -1443,7 +1450,7 @@ class DataQualityDict(OrderedDict):
 
         # read segment definers and generate DataQualityFlag object
         for row in segmentdeftable:
-            ifos = row.get_ifos()
+            ifos = sorted(row.instruments)
             ifo = ''.join(ifos) if ifos else None
             tag = row.name
             version = row.version
@@ -1451,10 +1458,11 @@ class DataQualityDict(OrderedDict):
                              k is not None])
             if names is None or name in names:
                 out[name] = DataQualityFlag(name)
+                thisid = int(row.segment_def_id)
                 try:
-                    id_[name].append(row.segment_def_id)
+                    id_[name].append(thisid)
                 except (AttributeError, KeyError):
-                    id_[name] = [row.segment_def_id]
+                    id_[name] = [thisid]
 
         # verify all requested flags were found
         for flag in names or []:
@@ -1466,52 +1474,71 @@ class DataQualityDict(OrderedDict):
                 else:
                     raise ValueError(msg)
 
+        # parse a table into the target DataQualityDict
+        def _parse_segments(table, listattr):
+            for row in table:
+                for flag in out:
+                    # match row ID to list of IDs found for this flag
+                    if int(row.segment_def_id) in id_[flag]:
+                        getattr(out[flag], listattr).append(
+                            Segment(*map(gpstype, row.segment)),
+                        )
+                        break
+
         # read segment summary table as 'known'
-        for row in segmentsumtable:
-            for flag in out:
-                # match row ID to list of IDs found for this flag
-                if row.segment_def_id in id_[flag]:
-                    out[flag].known.append(
-                        Segment(*map(gpstype, row.segment)))
-                    break
+        _parse_segments(segmentsumtable, "known")
 
         # read segment table as 'active'
-        for row in segmenttable:
-            for flag in out:
-                if row.segment_def_id in id_[flag]:
-                    out[flag].active.append(
-                        Segment(*map(gpstype, row.segment)))
-                    break
+        _parse_segments(segmenttable, "active")
 
         return out
 
-    def to_ligolw_tables(self, **attrs):
+    def to_ligolw_tables(self, ilwdchar_compat=None, **attrs):
         """Convert this `DataQualityDict` into a trio of LIGO_LW segment tables
 
         Parameters
         ----------
+        ilwdchar_compat : `bool`, optional
+            whether to write in the old format, compatible with
+            ILWD characters (`True`), or to use the new format (`False`);
+            the current default is `True` to maintain backwards
+            compatibility, but this will change for gwpy-1.0.0.
+
         **attrs
             other attributes to add to all rows in all tables
             (e.g. ``'process_id'``)
 
         Returns
         -------
-        segmentdeftable : :class:`~glue.ligolw.lsctables.SegmentDefTable`
+        segmentdeftable : :class:`~ligo.lw.lsctables.SegmentDefTable`
             the ``segment_definer`` table
 
-        segmentsumtable : :class:`~glue.ligolw.lsctables.SegmentSumTable`
+        segmentsumtable : :class:`~ligo.lw.lsctables.SegmentSumTable`
             the ``segment_summary`` table
 
-        segmenttable : :class:`~glue.ligolw.lsctables.SegmentTable`
+        segmenttable : :class:`~ligo.lw.lsctables.SegmentTable`
             the ``segment`` table
         """
-        from glue.ligolw.lsctables import (SegmentTable, SegmentSumTable,
-                                           SegmentDefTable, New as new_table)
+        if ilwdchar_compat is None:
+            warnings.warn("ilwdchar_compat currently defaults to `True`, "
+                          "but this will change to `False` in the future, to "
+                          "maintain compatibility in future releases, "
+                          "manually specify `ilwdchar_compat=True`",
+                          PendingDeprecationWarning)
+            ilwdchar_compat = True
+
+        if ilwdchar_compat:
+            from glue.ligolw import lsctables
+        else:
+            from ligo.lw import lsctables
         from ..io.ligolw import to_table_type as to_ligolw_table_type
 
-        segdeftab = new_table(SegmentDefTable)
-        segsumtab = new_table(SegmentSumTable)
-        segtab = new_table(SegmentTable)
+        SegmentDefTable = lsctables.SegmentDefTable
+        SegmentSumTable = lsctables.SegmentSumTable
+        SegmentTable = lsctables.SegmentTable
+        segdeftab = lsctables.New(SegmentDefTable)
+        segsumtab = lsctables.New(SegmentSumTable)
+        segtab = lsctables.New(SegmentTable)
 
         def _write_attrs(table, row):
             for key, val in attrs.items():
@@ -1523,7 +1550,7 @@ class DataQualityDict(OrderedDict):
             segdef = segdeftab.RowType()
             for col in segdeftab.columnnames:  # default all columns to None
                 setattr(segdef, col, None)
-            segdef.set_ifos([flag.ifo])
+            segdef.instruments = {flag.ifo}
             segdef.name = flag.tag
             segdef.version = flag.version
             segdef.comment = flag.description
@@ -1538,7 +1565,7 @@ class DataQualityDict(OrderedDict):
                 for col in segsumtab.columnnames:  # default columns to None
                     setattr(segsum, col, None)
                 segsum.segment_def_id = segdef.segment_def_id
-                segsum.set(map(LIGOTimeGPS, vseg))
+                segsum.segment = map(LIGOTimeGPS, vseg)
                 segsum.comment = None
                 segsum.segment_sum_id = SegmentSumTable.get_next_id()
                 _write_attrs(segsumtab, segsum)
@@ -1550,7 +1577,7 @@ class DataQualityDict(OrderedDict):
                 for col in segtab.columnnames:  # default all columns to None
                     setattr(seg, col, None)
                 seg.segment_def_id = segdef.segment_def_id
-                seg.set(map(LIGOTimeGPS, aseg))
+                seg.segment = map(LIGOTimeGPS, aseg)
                 seg.segment_id = SegmentTable.get_next_id()
                 _write_attrs(segtab, seg)
                 segtab.append(seg)
@@ -1785,7 +1812,7 @@ class DataQualityDict(OrderedDict):
         figure : `~matplotlib.figure.Figure`
             the newly created figure, with populated Axes.
 
-        See Also
+        See also
         --------
         matplotlib.pyplot.figure
             for documentation of keyword arguments used to create the
