@@ -34,6 +34,7 @@ from six.moves import xrange
 import numpy
 from numpy import fft as npfft
 
+from ..utils import round_to_power
 from ..segments import Segment
 
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
@@ -184,11 +185,13 @@ class QTiling(QObject):
         N : `int`
             estimated number of statistically independent tiles
 
-        See Also
+        See also
         --------
         QPlane.transform
             compute the Q-transform over a single time-frequency plane
         """
+        if not numpy.isfinite(fseries).all():
+            raise ValueError('Input signal contains non-numerical values')
         weight = 1 + numpy.log10(self.qrange[1]/self.qrange[0]) / numpy.sqrt(2)
         nind, nplanes, peak, result = (0, 0, 0, None)
         # identify the plane with the loudest tile
@@ -255,10 +258,15 @@ class QPlane(QBase):
         fstep = fcum_mismatch / nfreq
         fstepmin = 1 / self.duration
         # for each frequency, yield a QTile
+        last = None
         for i in xrange(nfreq):
-            yield (minf *
-                   exp(2 / (2 + self.q**2)**(1/2.) * (i + .5) * fstep) //
-                   fstepmin * fstepmin)
+            this = (
+                minf * exp(2 / (2 + self.q**2)**(1/2.) * (i + .5) * fstep) //
+                fstepmin * fstepmin
+            )
+            if this != last:  # yield only unique elements
+                yield this
+            last = this
 
     @property
     def frequencies(self):
@@ -281,7 +289,8 @@ class QPlane(QBase):
     def whitening_duration(self):
         """The recommended data duration required for whitening
         """
-        return 2 ** (round(log(self.q / (2 * self.frange[0]), 2)))
+        return round_to_power(self.q / (2 * self.frange[0]),
+                              base=2, which=None)
 
     def transform(self, fseries, norm=True, epoch=None, search=None):
         """Calculate the energy `TimeSeries` for the given `fseries`
@@ -310,7 +319,7 @@ class QPlane(QBase):
             the complex energies of the Q-transform of the input `fseries`
             at each frequency
 
-        See Also
+        See also
         --------
         QTile.transform
             for details on the transform over a row of `(Q, frequency)` tiles
@@ -347,7 +356,8 @@ class QTile(QBase):
         :type: `int`
         """
         tcum_mismatch = self.duration * 2 * pi * self.frequency / self.q
-        return next_power_of_two(tcum_mismatch / self.deltam)
+        return round_to_power(tcum_mismatch / self.deltam,
+                              base=2, which='upper')
 
     @property
     def windowsize(self):
@@ -508,7 +518,7 @@ class QGram(object):
         out : `~gwpy.spectrogram.Spectrogram`
             output `Spectrogram` of normalised Q energy
 
-        See Also
+        See also
         --------
         scipy.interpolate
             this method uses `~scipy.interpolate.InterpolatedUnivariateSpline`
@@ -626,12 +636,6 @@ class QGram(object):
 
 # -- utilities ----------------------------------------------------------------
 
-def next_power_of_two(x):
-    """Return the smallest power of two greater than or equal to `x`
-    """
-    return 2**(ceil(log(x, 2)))
-
-
 def q_scan(data, mismatch=DEFAULT_MISMATCH, qrange=DEFAULT_QRANGE,
            frange=DEFAULT_FRANGE, duration=None, sampling=None,
            **kwargs):
