@@ -27,7 +27,7 @@ from . import utils
 # other readers are defined in their own modules, and are responsible
 # for applying the decorators themselves.
 from . import (
-    ligolw,  # glue.ligolw XML format
+    ligolw,  # ligo.lw XML format
     root,  # generic ROOT stuff
     omicron,  # Omicron ROOT format
     omega,  # Omega ASCII format
@@ -36,6 +36,7 @@ from . import (
     hacr,  # Hierarchichal Algorithm for Curves and Ridges
     gwf,  # GWF FrEvents (e.g. MBTA)
     gravityspy,  # Gravity Spy Triggers
+    snax,  # SNAX HDF5 features
 )
 
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
