@@ -28,9 +28,10 @@ from six import string_types
 
 import numpy
 
+from gwosc.api import DEFAULT_URL as DEFAULT_GWOSC_URL
+
 from astropy.table import (Table, Column, vstack)
 from astropy.io import registry
-from astropy.units import Quantity
 
 from ..io.mp import read_multi as io_read_multi
 from ..time import gps_types
@@ -108,6 +109,11 @@ def _rates_preprocess(func):
 class EventColumn(Column):
     """Custom `Column` that allows filtering with segments
     """
+    def __new__(cls, *args, **kwargs):
+        warnings.warn("the EventColumn is deprecated, and will be removed in "
+                      "a future gwpy release", DeprecationWarning)
+        super(EventColumn, cls).__new__(*args, **kwargs)
+
     def in_segmentlist(self, segmentlist):
         """Return the index of values lying inside the given segmentlist
 
@@ -132,23 +138,17 @@ class EventColumn(Column):
 
 @inherit_io_registrations
 class EventTable(Table):
-    """A container for a table of events
+    """A container for a table of events.
 
-    This differs from the basic `~astropy.table.Table` in two ways
-
-    - GW-specific file formats are registered to use with
-      `EventTable.read` and `EventTable.write`
-    - columns of this table are of the `EventColumn` type, which provides
-      methods for filtering based on a `~gwpy.segments.SegmentList` (not
-      specifically time segments)
+    This object expands the default :class:`~astropy.table.Table`
+    with extra read/write formats, and methods to perform filtering,
+    rate calculations, and visualisation.
 
     See also
     --------
     astropy.table.Table
         for details on parameters for creating an `EventTable`
     """
-    Column = EventColumn
-
     # -- utilities ------------------------------
 
     def _get_time_column(self):
@@ -161,18 +161,26 @@ class EventTable(Table):
 
         So, its not foolproof.
         """
-        if 'time' in self.columns:
-            return 'time'
+        tcols = [
+            "time",  # standard
+            "tc",  # GWOSC catalogues
+            "peakGPS",  # gravityspy
+        ]
+        for col in tcols:
+            if col in self.columns:
+                return col
         try:
             time, = [name for name in self.columns if
                      isinstance(self[name][0], gps_types)]
-        except (ValueError, IndexError) as exc:
-            msg = ('cannot identify time column for table, no column '
-                   'named \'time\' and none with GPS dtypes')
-            if isinstance(exc, IndexError):
-                raise ValueError(msg)
-            exc.args = (msg,)
-            raise
+        except (ValueError, IndexError):
+            msg = (
+                "cannot identify time column for table, no column "
+                "named {0}, or {1!r}, and none with GPS dtypes".format(
+                    ", ".join(map(repr, tcols[:-1])),
+                    tcols[-1],
+                )
+            )
+            raise ValueError(msg)
         return time
 
     # -- i/o ------------------------------------
@@ -227,6 +235,8 @@ class EventTable(Table):
         ------
         astropy.io.registry.IORegistryError
             if the `format` cannot be automatically identified
+        IndexError
+            if ``source`` is an empty list
 
         Notes
         -----"""
@@ -327,13 +337,43 @@ class EventTable(Table):
         fetcher = get_fetcher(format_, cls)
         return fetcher(*args, **kwargs)
 
+    @classmethod
+    def fetch_open_data(cls, catalog, columns=None, selection=None,
+                        host=DEFAULT_GWOSC_URL, **kwargs):
+        """Fetch events from an open-data catalogue hosted by GWOSC.
+
+        Parameters
+        ----------
+        catalog : `str`
+            the name of the catalog to fetch, e.g. ``'GWTC-1-confident'``
+
+        columns : `list` of `str`, optional
+            the list of column names to read
+
+        selection : `str`, or `list` of `str`, optional
+            one or more column filters with which to downselect the
+            returned events as they as read, e.g. ``'mass1 < 30'``;
+            multiple selections should be connected by ' && ', or given as
+            a `list`, e.g. ``'mchirp < 3 && distance < 500'`` or
+            ``['mchirp < 3', 'distance < 500']``
+
+        host : `str`, optional
+            the open-data host to use
+        """
+        from .io.losc import fetch_catalog
+        tab = fetch_catalog(catalog, columns=columns, selection=selection,
+                            host=host, **kwargs)
+        if type(tab) is cls:  # don't copy unless we need to
+            return tab
+        return cls(tab)
+
     # -- ligolw compatibility -------------------
 
     def get_column(self, name):
         """Return the `Column` with the given name
 
         This method is provided only for compatibility with the
-        :class:`glue.ligolw.table.Table`.
+        :class:`ligo.lw.table.Table`.
 
         Parameters
         ----------
@@ -503,7 +543,7 @@ class EventTable(Table):
         plot : `~gwpy.plot.Plot`
             the newly created figure
 
-        See Also
+        See also
         --------
         matplotlib.pyplot.figure
             for documentation of keyword arguments used to create the
@@ -547,7 +587,7 @@ class EventTable(Table):
         plot : `~gwpy.plot.Plot`
             the newly created figure
 
-        See Also
+        See also
         --------
         matplotlib.pyplot.figure
             for documentation of keyword arguments used to create the
@@ -588,7 +628,7 @@ class EventTable(Table):
             name = col.name
             if rcParams['text.usetex']:
                 name = r'\texttt{{{0}}}'.format(label_to_latex(col.name))
-            if isinstance(col, Quantity):
+            if col.unit is not None:
                 name += ' [{0}]'.format(col.unit.to_string('latex_inline'))
             axis.set_label_text(name)
             axis.isDefault_label = True
@@ -615,7 +655,7 @@ class EventTable(Table):
         plot : `~gwpy.plot.Plot`
             The newly created figure.
 
-        See Also
+        See also
         --------
         matplotlib.pyplot.figure
             for documentation of keyword arguments used to create the
@@ -666,3 +706,66 @@ class EventTable(Table):
         >>> filter(my_table, ('time', in_segmentlist, segs))
         """
         return filter_table(self, *column_filters)
+
+    def cluster(self, index, rank, window):
+        """Cluster this `EventTable` over a given column, `index`, maximizing
+        over a specified column in the table, `rank`.
+
+        The clustering algorithm uses a pooling method to identify groups
+        of points that are all separated in `index` by less than `window`.
+
+        Each cluster of nearby points is replaced by the point in that cluster
+        with the maximum value of `rank`.
+
+        Parameters
+        ----------
+        index : `str`
+            name of the column which is used to search for clusters
+
+        rank : `str`
+            name of the column to maximize over in each cluster
+
+        window : `float`
+            window to use when clustering data points, will raise
+            ValueError if `window > 0` is not satisfied
+
+        Returns
+        -------
+        table : `EventTable`
+            a new table that has had the clustering algorithm applied via
+            slicing of the original
+
+        Examples
+        --------
+        To cluster an `EventTable` (``table``) whose `index` is
+        `end_time`, `window` is `0.1`, and maximize over `snr`:
+
+        >>> table.cluster('end_time', 'snr', 0.1)
+        """
+        if window <= 0.0:
+            raise ValueError('Window must be a positive value')
+
+        # Generate index and rank vectors that are ordered
+        orderidx = numpy.argsort(self[index])
+        col = self[index][orderidx]
+        param = self[rank][orderidx]
+
+        # Find all points where the index vector changes by less than window
+        # and divide the resulting array into clusters of adjacent points
+        clusterpoints = numpy.where(numpy.diff(col) <= window)[0]
+        sublists = numpy.split(clusterpoints,
+                               numpy.where(numpy.diff(clusterpoints) > 1)[0]+1)
+
+        # Add end-points to each cluster and find the index of the maximum
+        # point in each list
+        padded_sublists = [numpy.append(s, numpy.array([s[-1]+1]))
+                           for s in sublists]
+        maxidx = [s[numpy.argmax(param[s])] for s in padded_sublists]
+
+        # Construct a mask that removes all points within clusters and
+        # replaces them with the maximum point from each cluster
+        mask = numpy.ones_like(col, dtype=bool)
+        mask[numpy.concatenate(padded_sublists)] = False
+        mask[maxidx] = True
+
+        return self[orderidx[mask]]
