@@ -23,14 +23,18 @@ import os.path
 import shutil
 import tempfile
 from io import BytesIO
+from ssl import SSLError
 
 from six import PY2
+from six.moves.urllib.error import URLError
 
 import pytest
 
 import sqlparse
 
-from numpy import (random, isclose, dtype)
+from numpy import (random, isclose, dtype, asarray, all)
+from numpy.testing import assert_array_equal
+from numpy.ma.core import MaskedConstant
 
 import h5py
 
@@ -79,7 +83,7 @@ def mock_hacr_connection(table, start, stop):
                 str, list(cursor._query.get_sublists())[0].get_identifiers()))
             selections = list(map(
                 str, list(cursor._query.get_sublists())[2].get_sublists()))
-            return filter_table(table, selections[3:])[columns]
+            return map(tuple, filter_table(table, selections[3:])[columns])
 
     cursor.fetchall = fetchall
 
@@ -115,9 +119,43 @@ class TestTable(object):
     def table(cls):
         return cls.create(100, ['time', 'snr', 'frequency'])
 
+    @classmethod
+    @pytest.fixture()
+    def clustertable(cls):
+        return cls.TABLE(data=[[11, 1, 1, 10, 1, 1, 9],
+                               [0.0, 1.9, 1.95, 2.0, 2.05, 2.1, 4.0]],
+                         names=['amplitude', 'time'])
+
+    @staticmethod
+    @pytest.fixture()
+    def llwtable():
+        from ligo.lw.lsctables import (New, SnglBurstTable)
+        llwtab = New(SnglBurstTable, columns=["peak_frequency", "snr"])
+        for i in range(10):
+            row = llwtab.RowType()
+            row.peak_frequency = float(i)
+            row.snr = float(i)
+            llwtab.append(row)
+        return llwtab
+
     # -- test I/O -------------------------------
 
-    @utils.skip_missing_dependency('glue.ligolw.lsctables')
+    @utils.skip_missing_dependency('ligo.lw.lsctables')
+    def test_ligolw(self, llwtable):
+        tab = self.TABLE(llwtable)
+        assert set(tab.colnames) == {"peak_frequency", "snr"}
+        assert_array_equal(tab["snr"], llwtable.getColumnByName("snr"))
+
+    @utils.skip_missing_dependency('ligo.lw.lsctables')
+    def test_ligolw_rename(self, llwtable):
+        tab = self.TABLE(llwtable, rename={"peak_frequency": "frequency"})
+        assert set(tab.colnames) == {"frequency", "snr"}
+        assert_array_equal(
+            tab["frequency"],
+            llwtable.getColumnByName("peak_frequency"),
+        )
+
+    @utils.skip_missing_dependency('ligo.lw.lsctables')
     @pytest.mark.parametrize('ext', ['xml', 'xml.gz'])
     def test_read_write_ligolw(self, ext):
         table = self.create(
@@ -144,7 +182,7 @@ class TestTable(object):
             assert t2.meta.get('tablename', None) == 'sngl_burst'
 
             # check numpy type casting works
-            from glue.ligolw.lsctables import LIGOTimeGPS as LigolwGPS
+            from ligo.lw.lsctables import LIGOTimeGPS as LigolwGPS
             t3 = _read(columns=['peak'])
             assert isinstance(t3['peak'][0], LigolwGPS)
             t3 = _read(columns=['peak'], use_numpy_dtypes=True)
@@ -206,6 +244,52 @@ class TestTable(object):
                                       'one sngl_burst table')
 
     @utils.skip_missing_dependency('glue.ligolw.lsctables')
+    def test_read_write_ligolw_ilwdchar_compat(self):
+        from glue.ligolw.ilwd import get_ilwdchar_class
+        from glue.ligolw.lsctables import SnglBurstTable
+
+        eid_type = get_ilwdchar_class("sngl_burst", "event_id")
+
+        table = self.create(
+            100,
+            ["peak", "snr", "central_freq", "event_id"],
+            ["f8", "f4", "f4", "i8"],
+        )
+        with tempfile.NamedTemporaryFile(suffix=".xml") as tmp:
+            # write table with ilwdchar_compat=True
+            table.write(tmp, format="ligolw", tablename="sngl_burst",
+                        ilwdchar_compat=True)
+
+            # read raw ligolw and check type is correct
+            llw = io_ligolw.read_table(tmp, tablename="sngl_burst",
+                                       ilwdchar_compat=True)
+            assert type(llw.getColumnByName("event_id")[0]) is eid_type
+
+            # reset IDs to 0
+            SnglBurstTable.reset_next_id()
+
+            # read without explicit use of ilwdchar_compat
+            t2 = self.TABLE.read(tmp, columns=table.colnames)
+            assert type(t2[0]["event_id"]) is eid_type
+
+            # read again with explicit use of ilwdchar_compat
+            SnglBurstTable.reset_next_id()
+            utils.assert_table_equal(
+                self.TABLE.read(tmp, columns=table.colnames,
+                                ilwdchar_compat=True),
+                t2,
+            )
+
+            # and check that ilwdchar_compat=True, use_numpy_dtypes=True works
+            SnglBurstTable.reset_next_id()
+            utils.assert_table_equal(
+                self.TABLE.read(tmp, columns=table.colnames,
+                                ilwdchar_compat=True, use_numpy_dtypes=True),
+                table,
+                almost_equal=True,
+            )
+
+    @utils.skip_missing_dependency('ligo.lw.lsctables')
     def test_read_write_ligolw_property_columns(self):
         table = self.create(100, ['peak', 'snr', 'central_freq'],
                             ['f8', 'f4', 'f4'])
@@ -218,7 +302,10 @@ class TestTable(object):
             for col in ('peak_time', 'peak_time_ns'):
                 assert col in llw.columnnames
             with io_ligolw.patch_ligotimegps():
-                utils.assert_array_equal(llw.get_peak(), table['peak'])
+                utils.assert_array_equal(
+                    asarray([row.peak for row in llw]),
+                    table['peak'],
+                )
 
             # read table and assert gpsproperty was repacked properly
             t2 = self.TABLE.read(f, columns=table.colnames,
@@ -318,8 +405,10 @@ class TestEventTable(TestTable):
         # check compounding works
         loud = table.filter('snr > 100')
         lowfloud = table.filter('frequency < 100', 'snr > 100')
-        brute = type(table)(rows=[row for row in lowf if row in loud],
-                            names=table.dtype.names)
+        brute = type(table)(
+            rows=[tuple(row) for row in lowf if row in loud],
+            names=table.dtype.names,
+        )
         utils.assert_table_equal(brute, lowfloud)
 
         # check double-ended filter
@@ -334,8 +423,10 @@ class TestEventTable(TestTable):
         # check filtering on segments works
         segs = SegmentList([Segment(100, 200), Segment(400, 500)])
         inseg = table.filter(('time', filters.in_segmentlist, segs))
-        brute = type(table)(rows=[row for row in table if row['time'] in segs],
-                            names=table.colnames)
+        brute = type(table)(
+            rows=[tuple(row) for row in table if row['time'] in segs],
+            names=table.colnames,
+        )
         utils.assert_table_equal(inseg, brute)
 
         # check empty segmentlist is handled well
@@ -421,6 +512,29 @@ class TestEventTable(TestTable):
     def test_get_column(self, table):
         utils.assert_array_equal(table.get_column('snr'), table['snr'])
 
+    def test_cluster(self, clustertable):
+        # check that the central data points are all clustered away,
+        # the original table is unchanged, and all points return their
+        # intended values
+        t = clustertable.cluster('time', 'amplitude', 0.6)
+        assert len(t) == 3
+        assert len(clustertable) == 7
+        assert all(t['amplitude'] == [11, 10, 9])
+        assert all(t['time'] == [0.0, 2.0, 4.0])
+
+    def test_single_point_cluster(self, clustertable):
+        # check that a large cluster window returns at least one data point
+        t = clustertable.cluster('time', 'amplitude', 10)
+        assert len(t) == 1
+        assert all(t['amplitude'] == [11])
+        assert all(t['time'] == [0.0])
+
+    def test_cluster_window(self, clustertable):
+        # check that a non-positive window throws an appropriate ValueError
+        with pytest.raises(ValueError) as exc:
+            clustertable.cluster('time', 'amplitude', 0)
+        assert str(exc.value) == 'Window must be a positive value'
+
     # -- test I/O -------------------------------
 
     def test_read_write_hdf5(self, table):
@@ -595,6 +709,37 @@ class TestEventTable(TestTable):
             if os.path.isdir(os.path.dirname(fp)):
                 shutil.rmtree(os.path.dirname(fp))
 
+    def test_read_snax(self):
+        table = self.create(
+            100, names=['time', 'snr', 'frequency'])
+        fp = os.path.join(tempfile.mkdtemp(), 'SNAX-0-0.h5')
+        try:
+            # write table in snax format (by hand)
+            with h5py.File(fp, 'w') as h5f:
+                group = h5f.create_group('H1:FAKE')
+                group.create_dataset(data=table, name='0.0_20.0')
+
+            # check that we can read
+            t2 = self.TABLE.read(fp, 'H1:FAKE', format='hdf5.snax')
+            utils.assert_table_equal(table, t2)
+
+            # test with selection and columns
+            t2 = self.TABLE.read(
+                fp,
+                'H1:FAKE',
+                format='hdf5.snax',
+                selection='snr>.5',
+                columns=('time', 'snr'),
+            )
+            utils.assert_table_equal(
+                t2,
+                filter_table(table, 'snr>.5')[('time', 'snr')],
+            )
+
+        finally:
+            if os.path.isdir(os.path.dirname(fp)):
+                shutil.rmtree(os.path.dirname(fp))
+
     def test_fetch_hacr(self):
         table = self.create(100, names=HACR_COLUMNS)
         try:
@@ -623,3 +768,28 @@ class TestEventTable(TestTable):
             utils.assert_table_equal(
                 filter_table(table, 'freq_central>500')['gps_start', 'snr'],
                 t2)
+
+    def test_fetch_open_data(self):
+        try:
+            table = self.TABLE.fetch_open_data("GWTC-1-confident")
+        except (URLError, SSLError) as exc:
+            pytest.skip(str(exc))
+        assert len(table)
+        assert {"L_peak", "distance", "mass1"}.intersection(table.colnames)
+        # check unit parsing worked
+        assert table["distance"].unit == "Mpc"
+        # check that masking worked (needs table to be sorted)
+        gw170818 = table.loc["GW170818"]
+        assert isinstance(gw170818["snr_pycbc"], MaskedConstant)
+
+    def test_fetch_open_data_kwargs(self):
+        try:
+            table = self.TABLE.fetch_open_data(
+                "GWTC-1-confident",
+                selection="mass1 < 5",
+                columns=["name", "mass1", "mass2", "distance"])
+        except (URLError, SSLError) as exc:
+            pytest.skip(str(exc))
+        assert len(table) == 1
+        assert table[0]["name"] == "GW170817"
+        assert set(table.colnames) == {"name", "mass1", "mass2", "distance"}
