@@ -55,7 +55,6 @@ from gwosc.api import DEFAULT_URL as GWOSC_DEFAULT_HOST
 
 from ..types import Series
 from ..detector import (Channel, ChannelList)
-from ..io import datafind as io_datafind
 from ..segments import SegmentList
 from ..time import (Time, LIGOTimeGPS, gps_types, to_gps)
 from ..utils import gprint
@@ -304,6 +303,11 @@ class TimeSeriesBase(Series):
             value with which to fill gaps in the source data,
             by default gaps will result in a `ValueError`.
 
+        Raises
+        ------
+        IndexError
+            if ``source`` is an empty list
+
         Notes
         -----"""
         from .io.core import read as timeseries_reader
@@ -519,18 +523,14 @@ class TimeSeriesBase(Series):
             name of frametype in which this channel is stored, will search
             for containing frame types if necessary
 
-        pad : `float`, optional
-            value with which to fill gaps in the source data,
-            by default gaps will result in a `ValueError`.
-
-        scaled : `bool`, optional
-            apply slope and bias calibration to ADC data, for non-ADC data
-            this option has no effect.
-
         nproc : `int`, optional, default: `1`
             number of parallel processes to use, serial process by
             default.
 
+        pad : `float`, optional
+            value with which to fill gaps in the source data,
+            by default gaps will result in a `ValueError`.
+
         dtype : `numpy.dtype`, `str`, `type`, or `dict`
             numeric data type for returned data, e.g. `numpy.float`, or
             `dict` of (`channel`, `dtype`) pairs
@@ -611,7 +611,7 @@ class TimeSeriesBase(Series):
             :meth:`.find` (for direct GWF file access) or
             :meth:`.fetch` for remote NDS2 access
 
-        See Also
+        See also
         --------
         TimeSeries.fetch
             for grabbing data from a remote NDS2 server
@@ -633,7 +633,7 @@ class TimeSeriesBase(Series):
         figure : `~matplotlib.figure.Figure`
             the newly created figure, with populated Axes.
 
-        See Also
+        See also
         --------
         matplotlib.pyplot.figure
             for documentation of keyword arguments used to create the
@@ -965,7 +965,7 @@ class TimeSeriesBaseDict(OrderedDict):
         **kwargs
             other keyword arguments to send to `TimeSeries.append`
 
-        See Also
+        See also
         --------
         TimeSeries.append
             for details of the underlying series append operation
@@ -994,7 +994,7 @@ class TimeSeriesBaseDict(OrderedDict):
         **kwargs
             other keyword arguments to send to `TimeSeries.prepend`
 
-        See Also
+        See also
         --------
         TimeSeries.prepend
             for details of the underlying series prepend operation
@@ -1022,7 +1022,7 @@ class TimeSeriesBaseDict(OrderedDict):
             GPS end time of required data, defaults to end of data found;
             any input parseable by `~gwpy.time.to_gps` is fine
 
-        See Also
+        See also
         --------
         TimeSeries.crop
             for more details
@@ -1213,8 +1213,8 @@ class TimeSeriesBaseDict(OrderedDict):
             regular expression to use for frametype matching
 
         pad : `float`, optional
-            value with which to fill gaps in the source data, defaults to
-            'don't fill gaps'
+            value with which to fill gaps in the source data,
+            by default gaps will result in a `ValueError`.
 
         scaled : `bool`, optional
             apply slope and bias calibration to ADC data, for non-ADC data
@@ -1239,6 +1239,8 @@ class TimeSeriesBaseDict(OrderedDict):
         **readargs
             any other keyword arguments to be passed to `.read()`
         """
+        from ..io import datafind as io_datafind
+
         start = to_gps(start)
         end = to_gps(end)
 
@@ -1281,7 +1283,13 @@ class TimeSeriesBaseDict(OrderedDict):
                     exc.args = "Cannot parse list of IFOs from channel names",
                     raise
             # find frames
-            cache = io_datafind.find_urls(observatory, frametype, start, end)
+            cache = io_datafind.find_urls(
+                observatory,
+                frametype,
+                start,
+                end,
+                on_gaps="error" if pad is None else "warn",
+            )
             if not cache:
                 raise RuntimeError("No %s-%s frame files found for [%d, %d)"
                                    % (observatory, frametype, start, end))
@@ -1321,8 +1329,8 @@ class TimeSeriesBaseDict(OrderedDict):
             will search for all required frame types
 
         pad : `float`, optional
-            value with which to fill gaps in the source data, only used if
-            gap is not given, or `gap='pad'` is given
+            value with which to fill gaps in the source data,
+            by default gaps will result in a `ValueError`.
 
         scaled : `bool`, optional
             apply slope and bias calibration to ADC data, for non-ADC data
@@ -1587,8 +1595,9 @@ class TimeSeriesBaseList(list):
 
         Parameters
         ----------
-        pad : `float`, optional, default: `0.0`
-            value with which to pad gaps
+        pad : `float`, optional
+            value with which to fill gaps in the source data,
+            by default gaps will result in a `ValueError`.
 
         gap : `str`, optional, default: `'raise'`
             what to do if there are gaps in the data, one of
@@ -1605,7 +1614,7 @@ class TimeSeriesBaseList(list):
         series : `gwpy.types.TimeSeriesBase` subclass
              a single series containing all data from each entry in this list
 
-        See Also
+        See also
         --------
         TimeSeries.append
             for details on how the individual series are concatenated together
