@@ -40,7 +40,8 @@ import numpy
 
 from astropy.io.registry import (get_reader, get_writer)
 
-from ....segments import Segment
+from ligo.segments import segment as LigoSegment
+
 from ....time import to_gps
 from ....io.gwf import identify_gwf
 from ....io import cache as io_cache
@@ -251,7 +252,10 @@ def register_gwf_api(library):
         # separate cache into contiguous segments
         if io_cache.is_cache(source):
             if start is not None and end is not None:
-                source = io_cache.sieve(source, segment=Segment(start, end))
+                source = io_cache.sieve(
+                    source,
+                    segment=LigoSegment(start, end),
+                )
             source = list(io_cache.find_contiguous(source))
         # convert everything else into a list if needed
         if not isinstance(source, (list, tuple)):
@@ -305,8 +309,15 @@ def register_gwf_api(library):
 
     # -- write ----------------------------------
 
-    def write_timeseriesdict(data, outfile, start=None, end=None,
-                             name='gwpy', run=0):
+    def write_timeseriesdict(
+            data,
+            outfile,
+            start=None,
+            end=None,
+            type=None,
+            name='gwpy',
+            run=0,
+    ):
         """Write a `TimeSeriesDict` to disk in GWF format
 
         Parameters
@@ -325,6 +336,10 @@ def register_gwf_api(library):
             GPS end time of required data,
             any input parseable by `~gwpy.time.to_gps` is fine
 
+        type : `str`, optional
+            the type of the channel, one of 'adc', 'proc', 'sim', default
+            is 'proc' unless stored in the channel structure
+
         name : `str`, optional
             name of the project that created this GWF
 
@@ -335,8 +350,15 @@ def register_gwf_api(library):
         import_gwf_library(library)
 
         # then write using the relevant API
-        return libwrite_(data, outfile, start=start, end=end,
-                         name=name, run=run)
+        return libwrite_(
+            data,
+            outfile,
+            start=start,
+            end=end,
+            type=type,
+            name=name,
+            run=run,
+        )
 
     def write_timeseries(series, *args, **kwargs):
         """Write a `TimeSeries` to disk in GWF format
