@@ -27,9 +27,10 @@ from math import ceil
 
 import numpy
 
-from LDAStools import frameCPP
+from LDAStools import frameCPP  # noqa: F401
 
 from ....io import gwf as io_gwf
+from ....io import _framecpp as io_framecpp
 from ....io.utils import file_list
 from ....segments import Segment
 from ....time import LIGOTimeGPS
@@ -51,26 +52,6 @@ FRERR_NO_CHANNEL_OF_TYPE = re.compile(
     r'\ANo Fr(Adc|Proc|Sim)Data structures with the name ',
 )
 
-# get frameCPP type mapping
-NUMPY_TYPE_FROM_FRVECT = {
-    frameCPP.FrVect.FR_VECT_C: numpy.int8,
-    frameCPP.FrVect.FR_VECT_2S: numpy.int16,
-    frameCPP.FrVect.FR_VECT_4S: numpy.int32,
-    frameCPP.FrVect.FR_VECT_8S: numpy.int64,
-    frameCPP.FrVect.FR_VECT_4R: numpy.float32,
-    frameCPP.FrVect.FR_VECT_8R: numpy.float64,
-    frameCPP.FrVect.FR_VECT_8C: numpy.complex64,
-    frameCPP.FrVect.FR_VECT_16C: numpy.complex128,
-    frameCPP.FrVect.FR_VECT_STRING: numpy.string_,
-    frameCPP.FrVect.FR_VECT_1U: numpy.uint8,
-    frameCPP.FrVect.FR_VECT_2U: numpy.uint16,
-    frameCPP.FrVect.FR_VECT_4U: numpy.uint32,
-    frameCPP.FrVect.FR_VECT_8U: numpy.uint64,
-}
-
-FRVECT_TYPE_FROM_NUMPY = dict(
-    (v, k) for k, v in NUMPY_TYPE_FROM_FRVECT.items())
-
 
 class _Skip(ValueError):
     """Error denoting that the contents of a given structure aren't required
@@ -332,7 +313,6 @@ def read_frdata(frdata, epoch, start, end, scaled=True,
     except AttributeError:  # not FrAdcData
         slope = None
         bias = None
-        null_scaling = True
     else:
         null_scaling = slope == 1. and bias == 0.
 
@@ -347,12 +327,22 @@ def read_frdata(frdata, epoch, start, end, scaled=True,
         except _Skip:
             continue
 
-        # apply ADC scaling (only if interesting; this prevents unnecessary
-        #                                         type-casting errors)
-        if scaled and not null_scaling:
-            new *= slope
-            new += bias
-        if slope is not None:
+        # apply scaling for ADC channels
+        if scaled and slope is not None:
+            rtype = numpy.result_type(new, slope, bias)
+            typechange = not numpy.can_cast(
+                rtype,
+                new.dtype,
+                casting='same_kind',
+            )
+            # only apply scaling if interesting _or_ if it would lead to a
+            # type change, otherwise we are unnecessarily duplicating memory
+            if typechange:
+                new = new * slope + bias
+            elif not null_scaling:
+                new *= slope
+                new += bias
+        elif slope is not None:
             # user has deliberately disabled the ADC calibration, so
             # the stored engineering unit is not valid, revert to 'counts':
             new.override_unit('count')
@@ -453,51 +443,95 @@ def read_frvect(vect, epoch, start, end, name=None, series_class=TimeSeries):
 
 # -- write --------------------------------------------------------------------
 
-def write(tsdict, outfile, start=None, end=None, name='gwpy', run=0,
-          compression=257, compression_level=6):
+def write(tsdict, outfile,
+          start=None, end=None,
+          type=None,
+          name='gwpy', run=0,
+          compression='GZIP', compression_level=None):
     """Write data to a GWF file using the frameCPP API
+
+    Parameters
+    ----------
+    tsdict : `TimeSeriesDict`
+        dict of data to write
+
+    outfile : `str`
+        the file name of the target output file
+
+    start : `float`, optional
+        the GPS start time of the file
+
+    end : `float`, optional
+        the GPS end time of the file
+
+    type : `str`, optional
+        the type of the channel, one of 'adc', 'proc', 'sim', default
+        is 'proc' unless stored in the channel structure
+
+    name : `str`, optional
+        the name of each frame
+
+    run : `int`, optional
+        the FrameH run number
+
+    compression : `int`, `str`, optional
+        name of compresion algorithm to use, or its endian-appropriate
+        ID, choose from
+
+        - ``'RAW'``
+        - ``'GZIP'``
+        - ``'DIFF_GZIP'``
+        - ``'ZERO_SUPPRESS_WORD_2'``
+        - ``'ZERO_SUPPRESS_WORD_4'``
+        - ``'ZERO_SUPPRESS_WORD_8'``
+        - ``'ZERO_SUPPRESS_OTHERWISE_GZIP'``
+
+    compression_level : `int`, optional
+        compression level for given method, default is ``6`` for GZIP-based
+        methods, otherwise ``0``
     """
     # set frame header metadata
-    if not start:
-        starts = {LIGOTimeGPS(tsdict[key].x0.value) for key in tsdict}
-        if len(starts) != 1:
-            raise RuntimeError("Cannot write multiple TimeSeries to a single "
-                               "frame with different start times, "
-                               "please write into different frames")
-        start = list(starts)[0]
-    if not end:
-        ends = {tsdict[key].span[1] for key in tsdict}
-        if len(ends) != 1:
-            raise RuntimeError("Cannot write multiple TimeSeries to a single "
-                               "frame with different end times, "
-                               "please write into different frames")
-        end = list(ends)[0]
+    if not start or not end:
+        starts, ends = zip(*(ts.span for ts in tsdict.values()))
+        start = LIGOTimeGPS(start or min(starts))
+        end = LIGOTimeGPS(end or max(ends))
     duration = end - start
-    start = LIGOTimeGPS(start)
     ifos = {ts.channel.ifo for ts in tsdict.values() if
             ts.channel and ts.channel.ifo and
-            hasattr(frameCPP, 'DETECTOR_LOCATION_{0}'.format(ts.channel.ifo))}
+            ts.channel.ifo in io_framecpp.DetectorLocation}
 
     # create frame
-    frame = io_gwf.create_frame(time=start, duration=duration, name=name,
-                                run=run, ifos=ifos)
+    frame = io_gwf.create_frame(
+        time=start,
+        duration=duration,
+        name=name,
+        run=run,
+        ifos=ifos,
+    )
 
     # append channels
     for i, key in enumerate(tsdict):
-        try:
-            # pylint: disable=protected-access
-            ctype = tsdict[key].channel._ctype or 'proc'
-        except AttributeError:
-            ctype = 'proc'
-        append_to_frame(frame, tsdict[key].crop(start, end),
-                        type=ctype, channelid=i)
+        ctype = (
+            type or
+            getattr(tsdict[key].channel, "_ctype", "proc").lower() or
+            "proc"
+        )
+        if ctype == 'adc':
+            kw = {"channelid": i}
+        else:
+            kw = {}
+        _append_to_frame(frame, tsdict[key].crop(start, end), type=ctype, **kw)
 
     # write frame to file
-    io_gwf.write_frames(outfile, [frame], compression=compression,
-                        compression_level=compression_level)
+    io_gwf.write_frames(
+        outfile,
+        [frame],
+        compression=compression,
+        compression_level=compression_level,
+    )
 
 
-def append_to_frame(frame, timeseries, type='proc', channelid=0):
+def _append_to_frame(frame, timeseries, type='proc', **kwargs):
     # pylint: disable=redefined-builtin
     """Append data from a `TimeSeries` to a `~frameCPP.FrameH`
 
@@ -512,85 +546,36 @@ def append_to_frame(frame, timeseries, type='proc', channelid=0):
     type : `str`
         the type of the channel, one of 'adc', 'proc', 'sim'
 
-    channelid : `int`, optional
-        the ID of the channel within the group (only used for ADC channels)
-    """
-    if timeseries.channel:
-        channel = str(timeseries.channel)
-    else:
-        channel = str(timeseries.name)
+    **kwargs
+        other keyword arguments are passed to the relevant
+        `create_xxx` function
 
-    offset = float(LIGOTimeGPS(timeseries.t0.value) -
-                   LIGOTimeGPS(*frame.GetGTime()))
+    See also
+    --------
+    gwpy.io.gwf.create_fradcdata
+    gwpy.io.gwf.create_frprocdata
+    gwpy.io.gwf_create_frsimdata
+        for details of the data structure creation, and associated available
+        arguments
+    """
+    epoch = LIGOTimeGPS(*frame.GetGTime())
 
     # create the data container
     if type.lower() == 'adc':
-        frdata = frameCPP.FrAdcData(
-            channel,
-            0,  # channel group
-            channelid,  # channel number in group
-            16,  # number of bits in ADC
-            timeseries.sample_rate.value,  # sample rate
-        )
-        frdata.SetTimeOffset(offset)
+        create = io_gwf.create_fradcdata
         append = frame.AppendFrAdcData
     elif type.lower() == 'proc':
-        frdata = frameCPP.FrProcData(
-            channel,  # channel name
-            str(timeseries.name),  # comment
-            frameCPP.FrProcData.TIME_SERIES,  # ID as time-series
-            frameCPP.FrProcData.UNKNOWN_SUB_TYPE,  # empty sub-type (fseries)
-            offset,  # offset of first sample relative to frame start
-            abs(timeseries.span),  # duration of data
-            0.,  # heterodyne frequency
-            0.,  # phase of heterodyne
-            0.,  # frequency range
-            0.,  # resolution bandwidth
-        )
+        create = io_gwf.create_frprocdata
         append = frame.AppendFrProcData
     elif type.lower() == 'sim':
-        frdata = frameCPP.FrSimData(
-            str(timeseries.channel),  # channel name
-            str(timeseries.name),  # comment
-            timeseries.sample_rate.value,  # sample rate
-            offset,  # time offset of first sample
-            0.,  # heterodyne frequency
-            0.,  # phase of heterodyne
-        )
+        create = io_gwf.create_frsimdata
         append = frame.AppendFrSimData
     else:
         raise RuntimeError("Invalid channel type {!r}, please select one of "
                            "'adc, 'proc', or 'sim'".format(type))
+    frdata = create(timeseries, frame_epoch=epoch, **kwargs)
+
     # append an FrVect
-    frdata.AppendData(create_frvect(timeseries))
+    frdata.AppendData(io_gwf.create_frvect(timeseries))
     append(frdata)
-
-
-def create_frvect(timeseries):
-    """Create a `~frameCPP.FrVect` from a `TimeSeries`
-
-    This method is primarily designed to make writing data to GWF files a
-    bit easier.
-
-    Parameters
-    ----------
-    timeseries : `TimeSeries`
-        the input `TimeSeries`
-
-    Returns
-    -------
-    frvect : `~frameCPP.FrVect`
-        the output `FrVect`
-    """
-    # create timing dimension
-    dims = frameCPP.Dimension(
-        timeseries.size, timeseries.dx.value,
-        str(timeseries.dx.unit), 0)
-    # create FrVect
-    vect = frameCPP.FrVect(
-        timeseries.name or '', FRVECT_TYPE_FROM_NUMPY[timeseries.dtype.type],
-        1, dims, str(timeseries.unit))
-    # populate FrVect and return
-    vect.GetDataArray()[:] = numpy.require(timeseries.value,
-                                           requirements=['C'])
-    return vect
+    return frdata
