@@ -34,7 +34,7 @@ from six.moves import range
 
 import numpy
 
-from astropy import (units, __version__ as astropy_version)
+from astropy import units
 
 from .core import (TimeSeriesBase, TimeSeriesBaseDict, TimeSeriesBaseList,
                    as_series_dict_class)
@@ -198,10 +198,12 @@ class StateTimeSeries(TimeSeriesBase):
 
     # -- math handling (always boolean) ---------
 
-    if astropy_version >= '2.0.0':  # remove _if_ when we pin astropy >= 2.0.0
-        def __array_ufunc__(self, ufunc, method, *inputs, **kwargs):
-            return super(StateTimeSeries, self).__array_ufunc__(
-                ufunc, method, *inputs, **kwargs).view(bool)
+    def __array_ufunc__(self, ufunc, method, *inputs, **kwargs):
+        out = super(StateTimeSeries, self).__array_ufunc__(
+            ufunc, method, *inputs, **kwargs)
+        if out.ndim:
+            return out.view(bool)
+        return out
 
     def __array_wrap__(self, obj, context=None):
         return super(StateTimeSeries, self).__array_wrap__(
@@ -657,6 +659,11 @@ class StateVector(TimeSeriesBase):
             value with which to fill gaps in the source data, only used if
             gap is not given, or `gap='pad'` is given
 
+        Raises
+        ------
+        IndexError
+            if ``source`` is an empty list
+
         Examples
         --------
         To read the S6 state vector, with names for all the bits::
@@ -710,9 +717,9 @@ class StateVector(TimeSeriesBase):
             a list of `~gwpy.segments.flag.DataQualityFlag`
             reprensentations for each bit in this `StateVector`
 
-        See Also
+        See also
         --------
-        :meth:`StateTimeSeries.to_dqflag`
+        StateTimeSeries.to_dqflag
             for details on the segment representation method for
             `StateVector` bits
         """
@@ -814,7 +821,7 @@ class StateVector(TimeSeriesBase):
             :meth:`.find` (for direct GWF file access) or
             :meth:`.fetch` for remote NDS2 access
 
-        See Also
+        See also
         --------
         StateVector.fetch
             for grabbing data from a remote NDS2 server
@@ -852,7 +859,7 @@ class StateVector(TimeSeriesBase):
         plot : `~gwpy.plot.Plot`
             output plot object
 
-        See Also
+        See also
         --------
         matplotlib.pyplot.figure
             for documentation of keyword arguments used to create the
