@@ -45,10 +45,16 @@ from ...testing.compat import mock
 from ...time import LIGOTimeGPS
 from ...utils.misc import null_context
 from .. import (TimeSeries, TimeSeriesDict, TimeSeriesList, StateTimeSeries)
+from ..io.gwf import APIS as GWF_APIS
 from .test_core import (TestTimeSeriesBase as _TestTimeSeriesBase,
                         TestTimeSeriesBaseDict as _TestTimeSeriesBaseDict,
                         TestTimeSeriesBaseList as _TestTimeSeriesBaseList)
 
+SKIP_FRAMECPP = utils.skip_missing_dependency('LDAStools.frameCPP')
+SKIP_LAL = utils.skip_missing_dependency('lal')
+SKIP_LALFRAME = utils.skip_missing_dependency('lalframe')
+SKIP_PYCBC_PSD = utils.skip_missing_dependency('pycbc.psd')
+
 if scipy_version < '1.2.0':
     SCIPY_METHODS = ('welch', 'bartlett')
 else:
@@ -137,12 +143,8 @@ class TestTimeSeries(_TestTimeSeriesBase):
 
     @pytest.mark.parametrize('api', [
         None,
-        pytest.param(
-            'lalframe',
-            marks=utils.skip_missing_dependency('lalframe')),
-        pytest.param(
-            'framecpp',
-            marks=utils.skip_missing_dependency('LDAStools.frameCPP')),
+        pytest.param('lalframe', marks=SKIP_LALFRAME),
+        pytest.param('framecpp', marks=SKIP_FRAMECPP),
     ])
     def test_read_write_gwf(self, api):
         array = self.create(name='TEST')
@@ -215,9 +217,7 @@ class TestTimeSeries(_TestTimeSeriesBase):
                     exclude=['channel'])
 
     @pytest.mark.parametrize('api', [
-        pytest.param(
-            'framecpp',
-            marks=utils.skip_missing_dependency('LDAStools.frameCPP')),
+        pytest.param('framecpp', marks=SKIP_FRAMECPP),
     ])
     def test_read_write_gwf_error(self, api, losc):
         with utils.TemporaryFilename(suffix=".gwf") as tmp:
@@ -238,7 +238,7 @@ class TestTimeSeries(_TestTimeSeriesBase):
                 "Failed to read {0!r} from {1!r}".format(losc.name, tmp)
             )
 
-    @utils.skip_missing_dependency('lalframe')
+    @SKIP_LALFRAME
     def test_read_gwf_scaled_lalframe(self):
         with pytest.warns(None) as record:
             data = self.TEST_CLASS.read(
@@ -256,6 +256,51 @@ class TestTimeSeries(_TestTimeSeriesBase):
             )
         utils.assert_quantity_sub_equal(data, data2)
 
+    @SKIP_FRAMECPP
+    @SKIP_LALFRAME
+    @pytest.mark.parametrize("ctype", ("adc", "proc", "sim", None))
+    @pytest.mark.parametrize("format_", GWF_APIS)
+    def test_write_gwf_type(self, losc, format_, ctype):
+        from ...io.gwf import get_channel_type
+
+        # on debian, python=3, python-ldas-tools-framecpp < 2.6.9,
+        # the simdata test causes a segfault
+        import platform
+        import sys
+        if (
+            format_ == "framecpp" and
+            ctype == "sim" and
+            sys.version_info[0] >= 3 and
+            "debian" in platform.platform()
+        ):
+            pytest.xfail(
+                "reading Sim data with "
+                "python-ldas-tools-framecpp < 2.6.9 is broken"
+            )
+
+        gwfformat = "gwf.{}".format(format_)
+        expected_ctype = ctype if ctype else "proc"
+
+        with utils.TemporaryFilename(suffix=".gwf") as tmp:
+            losc.write(tmp, type=ctype, format=gwfformat)
+            assert get_channel_type(losc.name, tmp) == expected_ctype
+            try:
+                new = type(losc).read(tmp, losc.name, format=gwfformat)
+            except OverflowError:
+                # python-ldas-tools-framecpp < 2.6.9
+                if format_ == "framecpp" and ctype == "sim":
+                    pytest.xfail(
+                        "reading Sim data with "
+                        "python-ldas-tools-framecpp < 2.6.9 is broken"
+                    )
+                raise
+        # epoch seems to mismatch at O(1e-12), which is unfortunate
+        utils.assert_quantity_sub_equal(
+            losc,
+            new,
+            exclude=("channel", "x0"),
+        )
+
     @pytest.mark.parametrize('ext', ('hdf5', 'h5'))
     @pytest.mark.parametrize('channel', [
         None,
@@ -285,7 +330,7 @@ class TestTimeSeries(_TestTimeSeriesBase):
             # check that we can't then write the same data again
             with pytest.raises(IOError):
                 array.write(tmp)
-            with pytest.raises(RuntimeError):
+            with pytest.raises((RuntimeError, OSError, IOError)):
                 array.write(tmp, append=True)
 
             # check reading with start/end works
@@ -301,6 +346,27 @@ class TestTimeSeries(_TestTimeSeriesBase):
             assert_equal=utils.assert_quantity_sub_equal,
             assert_kw={'exclude': ['unit', 'name', 'channel', 'x0']})
 
+    def test_read_pad(self):
+        a = self.TEST_CLASS.read(
+            utils.TEST_HDF5_FILE,
+            "H1:LDAS-STRAIN",
+        )
+        b = self.TEST_CLASS.read(
+            utils.TEST_HDF5_FILE,
+            "H1:LDAS-STRAIN",
+            pad=0.,
+            start=a.span[0]-1,
+            end=a.span[1]+1,
+        )
+        utils.assert_quantity_sub_equal(
+            a.pad(
+                (int(a.sample_rate.value), int(a.sample_rate.value)),
+                mode="constant",
+                constant_values=(0,),
+            ),
+            b,
+        )
+
     @utils.skip_missing_dependency('nds2')
     def test_from_nds2_buffer_dynamic_scaled(self):
         # build fake buffer for LIGO channel
@@ -334,8 +400,7 @@ class TestTimeSeries(_TestTimeSeriesBase):
     @utils.skip_minimum_version("gwosc", "0.4.0")
     @pytest.mark.parametrize('format', [
         'hdf5',
-        pytest.param(  # only frameCPP actually reads units properly
-            'gwf', marks=utils.skip_missing_dependency('LDAStools.frameCPP')),
+        pytest.param('gwf', marks=SKIP_FRAMECPP),
     ])
     def test_fetch_open_data(self, losc, format):
         try:
@@ -406,10 +471,9 @@ class TestTimeSeries(_TestTimeSeriesBase):
             mock_connection.return_value = nds_connection
             with pytest.raises(RuntimeError) as exc:
                 self.TEST_CLASS.fetch('L1:TEST', 0, 1, host='nds.gwpy')
-            assert 'no data received' in str(exc)
+            assert 'no data received' in str(exc.value)
 
-    @utils.skip_missing_dependency('glue.datafind')
-    @utils.skip_missing_dependency('LDAStools.frameCPP')
+    @SKIP_FRAMECPP
     @pytest.mark.skipif('LIGO_DATAFIND_SERVER' not in os.environ,
                         reason='No LIGO datafind server configured '
                                'on this host')
@@ -428,8 +492,7 @@ class TestTimeSeries(_TestTimeSeriesBase):
             self.TEST_CLASS.find(FIND_CHANNEL, *LOSC_GW150914_SEGMENT,
                                  frametype=FIND_FRAMETYPE, observatory='X')
 
-    @utils.skip_missing_dependency('glue.datafind')
-    @utils.skip_missing_dependency('LDAStools.frameCPP')
+    @SKIP_FRAMECPP
     @pytest.mark.skipif('LIGO_DATAFIND_SERVER' not in os.environ,
                         reason='No LIGO datafind server configured '
                                'on this host')
@@ -450,8 +513,7 @@ class TestTimeSeries(_TestTimeSeriesBase):
             raise
         assert ft in expected
 
-    @utils.skip_missing_dependency('glue.datafind')
-    @utils.skip_missing_dependency('LDAStools.frameCPP')
+    @SKIP_FRAMECPP
     @pytest.mark.skipif('LIGO_DATAFIND_SERVER' not in os.environ,
                         reason='No LIGO datafind server configured '
                                'on this host')
@@ -518,16 +580,18 @@ class TestTimeSeries(_TestTimeSeriesBase):
             losc.psd(.5, .25, window='hann'),
         )
 
-    @utils.skip_missing_dependency('lal')
+    @SKIP_LAL
     def test_psd_lal_median_mean(self, losc):
         # check that warnings and errors get raised in the right place
         # for a median-mean PSD with the wrong data size or parameters
 
         # single segment should raise error
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError), pytest.deprecated_call():
             losc.psd(abs(losc.span), method='lal_median_mean')
 
         # odd number of segments should warn
+        # pytest hides the second DeprecationWarning that should have been
+        # triggered here, for some reason
         with pytest.warns(UserWarning):
             losc.psd(1, .5, method='lal_median_mean')
 
@@ -603,9 +667,14 @@ class TestTimeSeries(_TestTimeSeriesBase):
         return signal.get_window(window, nfft)
 
     @pytest.mark.parametrize('method', [
-        'scipy-welch', 'scipy-bartlett',
-        'lal-welch', 'lal-bartlett', 'lal-median',
-        'pycbc-welch', 'pycbc-bartlett', 'pycbc-median',
+        'scipy-welch',
+        'scipy-bartlett',
+        pytest.param('lal-welch', marks=SKIP_LAL),
+        pytest.param('lal-bartlett', marks=SKIP_LAL),
+        pytest.param('lal-median', marks=SKIP_LAL),
+        pytest.param('pycbc-welch', marks=SKIP_PYCBC_PSD),
+        pytest.param('pycbc-bartlett', marks=SKIP_PYCBC_PSD),
+        pytest.param('pycbc-median', marks=SKIP_PYCBC_PSD),
     ])
     @pytest.mark.parametrize(
         'window', (None, 'hann', ('kaiser', 24), 'array'),
@@ -614,13 +683,14 @@ class TestTimeSeries(_TestTimeSeriesBase):
         # generate window for 'array'
         win = self._window_helper(losc, 1) if window == 'array' else window
 
+        if method.startswith(("lal", "pycbc")):
+            ctx = pytest.deprecated_call
+        else:
+            ctx = null_context
+
         # generate spectrogram
-        try:
+        with ctx():
             sg = losc.spectrogram(1, method=method, window=win)
-        except ImportError as exc:
-            if method.startswith(('lal', 'pycbc')):
-                pytest.skip(str(exc))
-            raise
 
         # validate
         assert isinstance(sg, Spectrogram)
@@ -637,49 +707,48 @@ class TestTimeSeries(_TestTimeSeriesBase):
         n = int(losc.sample_rate.value)
         if window == 'hann' and not method.endswith('bartlett'):
             n *= 1.5  # default is 50% overlap
-        psd = losc[:int(n)].psd(fftlength=1, method=method, window=win)
+        with ctx():
+            psd = losc[:int(n)].psd(fftlength=1, method=method, window=win)
         # FIXME: epoch should not be excluded here (probably)
-        print(psd)
-        print(sg[0])
         utils.assert_quantity_sub_equal(sg[0], psd, exclude=['epoch'],
                                         almost_equal=True)
 
-        # test fftlength
-        win2 = self._window_helper(losc, .5) if window == 'array' else window
-        sg = losc.spectrogram(1, fftlength=0.5, window=win2)
+    def test_spectrogram_fftlength(self, losc):
+        sg = losc.spectrogram(1, fftlength=0.5)
         assert sg.shape == (abs(losc.span),
                             0.5 * losc.sample_rate.value // 2 + 1)
         assert sg.df == 2 * units.Hertz
         assert sg.dt == 1 * units.second
 
-        # test auto-overlap
-        if window == 'hann':
-            sg2 = losc.spectrogram(1, fftlength=0.5, overlap=.25,
-                                   window='hann')
-            utils.assert_quantity_sub_equal(sg, sg2, almost_equal=True)
+    def test_spectrogram_overlap(self, losc):
+        sg = losc.spectrogram(1, fftlength=0.5, window="hann")
+        sg2 = losc.spectrogram(1, fftlength=0.5, window="hann", overlap=.25)
+        utils.assert_quantity_sub_equal(sg, sg2, almost_equal=True)
 
-        # test multiprocessing
-        sg2 = losc.spectrogram(1, fftlength=0.5, nproc=2, window=win)
+    def test_spectrogram_multiprocessing(self, losc):
+        sg = losc.spectrogram(1, fftlength=0.5)
+        sg2 = losc.spectrogram(1, fftlength=0.5, nproc=2)
         utils.assert_quantity_sub_equal(sg, sg2, almost_equal=True)
 
     @pytest.mark.parametrize('library', [
-        pytest.param('lal', marks=utils.skip_missing_dependency('lal')),
-        pytest.param('pycbc',
-                     marks=utils.skip_missing_dependency('pycbc.psd')),
+        pytest.param('lal', marks=SKIP_LAL),
+        pytest.param('pycbc', marks=SKIP_PYCBC_PSD),
     ])
     def test_spectrogram_median_mean(self, losc, library):
         method = '{0}-median-mean'.format(library)
-        # median-mean will fail on pycbc, and warn on LAL, if not given
-        # the correct data for an even number of FFTs
 
+        # median-mean warn on LAL if not given the correct data for an
+        # even number of FFTs.
+        # pytest only asserts a single warning, and UserWarning will take
+        # precedence apparently, so check that for lal
         if library == 'lal':
-            with pytest.warns(UserWarning):
-                sg = losc.spectrogram(1.5, fftlength=.5, overlap=0,
-                                      method=method)
+            warn_ctx = pytest.warns(UserWarning)
         else:
+            warn_ctx = pytest.deprecated_call()
+
+        with warn_ctx:
             sg = losc.spectrogram(1.5, fftlength=.5, overlap=0, method=method)
 
-        # but should still work
         assert sg.dt == 1.5 * units.second
         assert sg.df == 2 * units.Hertz
 
@@ -840,6 +909,40 @@ class TestTimeSeries(_TestTimeSeriesBase):
         assert ph.unit == 'rad'
         utils.assert_allclose(ph.value, phase, rtol=1e-5)
 
+    def test_heterodyne(self):
+        # create a timeseries that is simply one loud sinusoidal oscillation,
+        # with a frequency and frequency derivative, then heterodyne using the
+        # phase evolution to recover the amplitude and phase
+        amp, phase, f, fdot = 1., numpy.pi/4, 30, 1e-4
+        duration, sample_rate, stride = 600, 4096, 60
+        t = numpy.linspace(0, duration, duration*sample_rate)
+        phases = 2*numpy.pi*(f*t + 0.5*fdot*t**2)
+        data = TimeSeries(amp * numpy.cos(phases + phase),
+                          unit='', times=t)
+
+        # test exceptions
+        with pytest.raises(TypeError):
+            data.heterodyne(1.0)
+
+        with pytest.raises(ValueError):
+            data.heterodyne(phases[0:len(phases) // 2])
+
+        # test with default settings
+        het = data.heterodyne(phases, stride=stride)
+        assert het.unit == data.unit
+        assert het.size == duration // stride
+        utils.assert_allclose(numpy.abs(het.value), 0.5*amp, rtol=1e-4)
+        utils.assert_allclose(numpy.angle(het.value), phase, rtol=2e-4)
+
+        # test with singlesided=True
+        het = data.heterodyne(
+            phases, stride=stride, singlesided=True
+        )
+        assert het.unit == data.unit
+        assert het.size == duration // stride
+        utils.assert_allclose(numpy.abs(het.value), amp, rtol=1e-4)
+        utils.assert_allclose(numpy.angle(het.value), phase, rtol=2e-4)
+
     def test_taper(self):
         # create a flat timeseries, then taper it
         t = numpy.linspace(0, 1, 2048)
@@ -854,6 +957,22 @@ class TestTimeSeries(_TestTimeSeriesBase):
         assert tapered.size == data.size
         utils.assert_allclose(data.value, numpy.cos(10*numpy.pi*t))
 
+        # run the same tests for a user-specified taper duration
+        dtapered = data.taper(duration=0.1)
+        assert dtapered[0].value == 0
+        assert dtapered[-1].value == 0
+        assert dtapered.unit == data.unit
+        assert dtapered.size == data.size
+        utils.assert_allclose(data.value, numpy.cos(10*numpy.pi*t))
+
+        # run the same tests for a user-specified number of samples to taper
+        stapered = data.taper(nsamples=10)
+        assert stapered[0].value == 0
+        assert stapered[-1].value == 0
+        assert stapered.unit == data.unit
+        assert stapered.size == data.size
+        utils.assert_allclose(data.value, numpy.cos(10*numpy.pi*t))
+
     def test_inject(self):
         # create a timeseries out of an array of zeros
         duration, sample_rate = 1, 4096
@@ -1050,6 +1169,12 @@ class TestTimeSeries(_TestTimeSeriesBase):
         assert qspecgram.q == 5.65685424949238
         nptest.assert_almost_equal(qspecgram.value.max(), 155.93774, decimal=5)
 
+    def test_q_transform_nan(self):
+        data = TimeSeries(numpy.empty(256*10) * numpy.nan, sample_rate=256)
+        with pytest.raises(ValueError) as exc:
+            data.q_transform()
+        assert str(exc.value) == 'Input signal contains non-numerical values'
+
     def test_boolean_statetimeseries(self, array):
         comp = array >= 2 * array.unit
         assert isinstance(comp, StateTimeSeries)
@@ -1088,7 +1213,7 @@ class TestTimeSeriesDict(_TestTimeSeriesBaseDict):
     TEST_CLASS = TimeSeriesDict
     ENTRY_CLASS = TimeSeries
 
-    @utils.skip_missing_dependency('LDAStools.frameCPP')
+    @SKIP_FRAMECPP
     def test_read_write_gwf(self, instance):
         with utils.TemporaryFilename(suffix='.gwf') as tmp:
             instance.write(tmp)
