@@ -147,10 +147,9 @@ class TimeSeries(TimeSeriesBase):
         out : `~gwpy.frequencyseries.FrequencySeries`
             the normalised, complex-valued FFT `FrequencySeries`.
 
-        See Also
+        See also
         --------
-        :mod:`scipy.fftpack` for the definition of the DFT and conventions
-        used.
+        numpy.fft.rfft : The FFT implementation used in this method.
 
         Notes
         -----
@@ -201,10 +200,10 @@ class TimeSeries(TimeSeriesBase):
             the transformed output, with populated frequencies array
             metadata
 
-        See Also
+        See also
         --------
-        :mod:`scipy.fftpack` for the definition of the DFT and conventions
-        used.
+        TimeSeries.fft
+           The FFT method used.
         """
         from gwpy.spectrogram import Spectrogram
         # format lengths
@@ -613,9 +612,9 @@ class TimeSeries(TimeSeriesBase):
         specvar : `SpectralVariance`
             2D-array of spectral frequency-amplitude counts
 
-        See Also
+        See also
         --------
-        :func:`numpy.histogram`
+        numpy.histogram
             for details on specifying bins and weights
 
         Notes
@@ -687,7 +686,7 @@ class TimeSeries(TimeSeriesBase):
             time-frequency Rayleigh spectrogram as generated from the
             input time-series.
 
-        See Also
+        See also
         --------
         TimeSeries.rayleigh
             for details of the statistic calculation
@@ -782,18 +781,18 @@ class TimeSeries(TimeSeriesBase):
         hpseries : `TimeSeries`
             a high-passed version of the input `TimeSeries`
 
-        See Also
+        See also
         --------
         gwpy.signal.filter_design.highpass
             for details on the filter design
         TimeSeries.filter
             for details on how the filter is applied
 
-        .. note::
-
-           When using `scipy < 0.16.0` some higher-order filters may be
-           unstable. With `scipy >= 0.16.0` higher-order filters are
-           decomposed into second-order-sections, and so are much more stable.
+        Notes
+        -----
+        When using `scipy < 0.16.0` some higher-order filters may be
+        unstable. With `scipy >= 0.16.0` higher-order filters are
+        decomposed into second-order-sections, and so are much more stable.
         """
         # design filter
         filt = filter_design.highpass(frequency, self.sample_rate,
@@ -832,18 +831,18 @@ class TimeSeries(TimeSeriesBase):
         lpseries : `TimeSeries`
             a low-passed version of the input `TimeSeries`
 
-        See Also
+        See also
         --------
         gwpy.signal.filter_design.lowpass
             for details on the filter design
         TimeSeries.filter
             for details on how the filter is applied
 
-        .. note::
-
-           When using `scipy < 0.16.0` some higher-order filters may be
-           unstable. With `scipy >= 0.16.0` higher-order filters are
-           decomposed into second-order-sections, and so are much more stable.
+        Notes
+        -----
+        When using `scipy < 0.16.0` some higher-order filters may be
+        unstable. With `scipy >= 0.16.0` higher-order filters are
+        decomposed into second-order-sections, and so are much more stable.
         """
         # design filter
         filt = filter_design.lowpass(frequency, self.sample_rate,
@@ -885,18 +884,18 @@ class TimeSeries(TimeSeriesBase):
         bpseries : `TimeSeries`
             a band-passed version of the input `TimeSeries`
 
-        See Also
+        See also
         --------
         gwpy.signal.filter_design.bandpass
             for details on the filter design
         TimeSeries.filter
             for details on how the filter is applied
 
-        .. note::
-
-           When using `scipy < 0.16.0` some higher-order filters may be
-           unstable. With `scipy >= 0.16.0` higher-order filters are
-           decomposed into second-order-sections, and so are much more stable.
+        Notes
+        -----
+        When using `scipy < 0.16.0` some higher-order filters may be
+        unstable. With `scipy >= 0.16.0` higher-order filters are
+        decomposed into second-order-sections, and so are much more stable.
         """
         # design filter
         filt = filter_design.bandpass(flow, fhigh, self.sample_rate,
@@ -988,7 +987,7 @@ class TimeSeries(TimeSeriesBase):
         timeseries : `TimeSeries`
             the filtered version of the input data
 
-        See Also
+        See also
         --------
         TimeSeries.filter
             for details on how a digital ZPK-format filter is applied
@@ -1043,11 +1042,9 @@ class TimeSeries(TimeSeriesBase):
         ``(numerator, denominator)`` representation before being applied
         to this `TimeSeries`.
 
-        .. note::
-
-           When using `scipy < 0.16` some higher-order filters may be
-           unstable. With `scipy >= 0.16` higher-order filters are
-           decomposed into second-order-sections, and so are much more stable.
+        When using `scipy < 0.16` some higher-order filters may be
+        unstable. With `scipy >= 0.16` higher-order filters are
+        decomposed into second-order-sections, and so are much more stable.
 
         FIR filters are passed directly to :func:`scipy.signal.lfilter` or
         :func:`scipy.signal.filtfilt` without any conversions.
@@ -1173,9 +1170,9 @@ class TimeSeries(TimeSeriesBase):
         :attr:`TimeSeries.sample_rate` values, the higher sampled
         `TimeSeries` will be down-sampled to match the lower.
 
-        See Also
+        See also
         --------
-        :func:`matplotlib.mlab.cohere`
+        matplotlib.mlab.cohere
             for details of the coherence calculator
         """
         from matplotlib import mlab
@@ -1257,9 +1254,9 @@ class TimeSeries(TimeSeriesBase):
         The :meth:`TimeSeries.auto_coherence` will perform best when
         ``dt`` is approximately ``fftlength / 2``.
 
-        See Also
+        See also
         --------
-        :func:`matplotlib.mlab.cohere`
+        matplotlib.mlab.cohere
             for details of the coherence calculator
         """
         # shifting self backwards is the same as forwards
@@ -1341,7 +1338,7 @@ class TimeSeries(TimeSeriesBase):
 
     def demodulate(self, f, stride=1, exp=False, deg=True):
         """Compute the average magnitude and phase of this `TimeSeries`
-        once per stride at a given frequency.
+        once per stride at a given frequency
 
         Parameters
         ----------
@@ -1391,21 +1388,17 @@ class TimeSeries(TimeSeriesBase):
         >>> ax = plot.gca()
         >>> ax.set_ylabel('Strain Amplitude at 331.3 Hz')
         >>> plot.show()
+
+        See also
+        --------
+        TimeSeries.heterodyne
+            for the underlying heterodyne detection method
         """
-        stridesamp = int(stride * self.sample_rate.value)
-        nsteps = int(self.size // stridesamp)
-        # stride through the TimeSeries and mix with a local oscillator,
-        # taking the average over each stride
-        out = type(self)(numpy.zeros(nsteps, dtype=complex))
-        out.__array_finalize__(self)
-        out.sample_rate = 1 / float(stride)
-        w = 2 * numpy.pi * f * self.dt.decompose().value
-        for step in range(nsteps):
-            istart = int(stridesamp * step)
-            iend = istart + stridesamp
-            idx = numpy.arange(istart, iend)
-            mixed = 2 * numpy.exp(-1j * w * idx) * self.value[idx]
-            out.value[step] = mixed.mean()
+        # stride through the TimeSeries and heterodyne at a single frequency
+        phase = (2 * numpy.pi * f *
+                 self.dt.decompose().value *
+                 numpy.arange(0, self.size))
+        out = self.heterodyne(phase, stride=stride, singlesided=True)
         if exp:
             return out
         mag = out.abs()
@@ -1414,7 +1407,115 @@ class TimeSeries(TimeSeriesBase):
         phase.override_unit('deg' if deg else 'rad')
         return (mag, phase)
 
-    def taper(self, side='leftright'):
+    def heterodyne(self, phase, stride=1, singlesided=False):
+        """Compute the average magnitude and phase of this `TimeSeries`
+        once per stride after heterodyning with a given phase series
+
+        Parameters
+        ----------
+        phase : `array_like`
+            an array of phase measurements (radians) with which to heterodyne
+            the signal
+
+        stride : `float`, optional
+            stride (seconds) between calculations, defaults to 1 second
+
+        singlesided : `bool`, optional
+            Boolean switch to return single-sided output (i.e., to multiply by
+            2 so that the signal is distributed across positive frequencies
+            only), default: False
+
+        Returns
+        -------
+        out : `TimeSeries`
+            magnitude and phase trends, represented as
+            `mag * exp(1j*phase)` with `dt=stride`
+
+        Notes
+        -----
+        This is similar to the :meth:`~gwpy.timeseries.TimeSeries.demodulate`
+        method, but is more general in that it accepts a varying phase
+        evolution, rather than a fixed frequency.
+
+        Unlike :meth:`~gwpy.timeseries.TimeSeries.demodulate`, the complex
+        output is double-sided by default, so is not multiplied by 2.
+
+        Examples
+        --------
+        Heterodyning can be useful in analysing quasi-monochromatic signals
+        with a known phase evolution, such as continuous-wave signals
+        from rapidly rotating neutron stars. These sources radiate at a
+        frequency that slowly decreases over time, and is Doppler modulated
+        due to the Earth's rotational and orbital motion.
+
+        To see an example of heterodyning in action, we can simulate a signal
+        whose phase evolution is described by the frequency and its first
+        derivative with respect to time. We can download some O1 era
+        LIGO-Livingston data from GWOSC, inject the simulated signal, and
+        recover its amplitude.
+
+        >>> from gwpy.timeseries import TimeSeries
+        >>> data = TimeSeries.fetch_open_data('L1', 1131350417, 1131354017)
+
+        We now need to set the signal parameters, generate the expected
+        phase evolution, and create the signal:
+
+        >>> import numpy
+        >>> f0 = 123.456789  # signal frequency (Hz)
+        >>> fdot = -9.87654321e-7  # signal frequency derivative (Hz/s)
+        >>> fpeoch = 1131350417  # phase epoch
+        >>> amp = 1.5e-22  # signal amplitude
+        >>> phase0 = 0.4  # signal phase at the phase epoch
+        >>> times = data.times.value - fepoch
+        >>> phase = 2 * numpy.pi * (f0 * times + 0.5 * fdot * times**2)
+        >>> signal = TimeSeries(amp * numpy.cos(phase + phase0),
+        >>>                     sample_rate=data.sample_rate, t0=data.t0)
+        >>> data = data.inject(signal)
+
+        To recover the signal, we can bandpass the injected data around the
+        signal frequency, then heterodyne using our phase model with a stride
+        of 60 seconds:
+
+        >>> filtdata = data.bandpass(f0 - 0.5, f0 + 0.5)
+        >>> het = filtdata.heterodyne(phase, stride=60, singlesided=True)
+
+        We can then plot signal amplitude over time (cropping the first two
+        minutes to remove the filter response):
+
+        >>> plot = het.crop(het.x0.value + 180).abs().plot()
+        >>> ax = plot.gca()
+        >>> ax.set_ylabel("Strain amplitude")
+        >>> plot.show()
+
+        See also
+        --------
+        TimeSeries.demodulate
+            for a method to heterodyne at a fixed frequency
+        """
+        try:
+            phaselen = len(phase)
+        except Exception as exc:
+            raise TypeError("Phase is not array_like: {}".format(exc))
+        if phaselen != len(self):
+            raise ValueError(
+                "Phase array must be the same length as the TimeSeries"
+            )
+        stridesamp = int(stride * self.sample_rate.value)
+        nsteps = int(self.size // stridesamp)
+        # stride through the TimeSeries and heterodyne
+        out = type(self)(numpy.zeros(nsteps, dtype=complex))
+        out.__array_finalize__(self)
+        out.sample_rate = 1 / float(stride)
+        phasearray = numpy.asarray(phase)  # make sure phase is a numpy array
+        for step in range(nsteps):
+            istart = int(stridesamp * step)
+            iend = istart + stridesamp
+            idx = numpy.arange(istart, iend)
+            mixed = numpy.exp(-1j * phasearray[idx]) * self.value[idx]
+            out.value[step] = 2 * mixed.mean() if singlesided else mixed.mean()
+        return out
+
+    def taper(self, side='leftright', duration=None, nsamples=None):
         """Taper the ends of this `TimeSeries` smoothly to zero.
 
         Parameters
@@ -1423,6 +1524,14 @@ class TimeSeries(TimeSeriesBase):
             the side of the `TimeSeries` to taper, must be one of `'left'`,
             `'right'`, or `'leftright'`
 
+        duration : `float`, optional
+            the duration of time to taper, will override `nsamples`
+            if both are provided as arguments
+
+        nsamples : `int`, optional
+            the number of samples to taper, will be overridden by `duration`
+            if both are provided as arguments
+
         Returns
         -------
         out : `TimeSeries`
@@ -1466,18 +1575,22 @@ class TimeSeries(TimeSeriesBase):
         if side not in ('left', 'right', 'leftright'):
             raise ValueError("side must be one of 'left', 'right', "
                              "or 'leftright'")
+        if duration:
+            nsamples = int(duration * self.sample_rate.to("Hz").value)
         out = self.copy()
+        # if a duration or number of samples is not specified, automatically
         # identify the second stationary point away from each boundary,
         # else default to half the TimeSeries width
         nleft, nright = 0, 0
-        mini, = signal.argrelmin(out.value)
-        maxi, = signal.argrelmax(out.value)
+        if not nsamples:
+            mini, = signal.argrelmin(out.value)
+            maxi, = signal.argrelmax(out.value)
         if 'left' in side:
-            nleft = max(mini[0], maxi[0])
-            nleft = min(nleft, self.size/2)
+            nleft = nsamples or max(mini[0], maxi[0])
+            nleft = min(nleft, int(self.size/2))
         if 'right' in side:
-            nright = out.size - min(mini[-1], maxi[-1])
-            nright = min(nright, self.size/2)
+            nright = nsamples or out.size - min(mini[-1], maxi[-1])
+            nright = min(nright, int(self.size/2))
         out *= planck(out.size, nleft=nleft, nright=nright)
         return out
 
@@ -1532,7 +1645,7 @@ class TimeSeries(TimeSeriesBase):
             a whitened version of the input data with zero mean and unit
             variance
 
-        See Also
+        See also
         --------
         TimeSeries.asd
             for details on the ASD calculation
@@ -1581,6 +1694,7 @@ class TimeSeries(TimeSeriesBase):
     def gate(self, tzero=1.0, tpad=0.5, whiten=True,
              threshold=50., cluster_window=0.5, **whiten_kwargs):
         """Removes high amplitude peaks from data using inverse Planck window.
+
         Points will be discovered automatically using a provided threshold
         and clustered within a provided time window.
 
@@ -1616,17 +1730,19 @@ class TimeSeries(TimeSeriesBase):
 
         Examples
         --------
-
         Read data into a `TimeSeries`
+
         >>> from gwpy.timeseries import TimeSeries
         >>> data = TimeSeries.fetch_open_data('H1', 1135148571, 1135148771)
 
         Apply gating using custom arguments
+
         >>> gated = data.gate(tzero=1.0, tpad=1.0, threshold=10.0,
                               fftlength=4, overlap=2, method='median')
 
         Plot the original data and the gated data, whiten both for
         visualization purposes
+
         >>> overlay = data.whiten(4,2,method='median').plot(dpi=150,
                                   label='Ungated', color='dodgerblue',
                                   zorder=2)
@@ -1690,7 +1806,7 @@ class TimeSeries(TimeSeriesBase):
         out : `TimeSeries`
             the result of the convolution
 
-        See Also
+        See also
         --------
         scipy.signal.fftconvolve
             for details on the convolution scheme used here
@@ -1777,7 +1893,7 @@ class TimeSeries(TimeSeriesBase):
         snr : `TimeSeries`
             the correlated signal-to-noise ratio (SNR) timeseries
 
-        See Also
+        See also
         --------
         TimeSeries.asd
             for details on the ASD calculation
@@ -1843,7 +1959,7 @@ class TimeSeries(TimeSeriesBase):
         detrended : `TimeSeries`
             the detrended input series
 
-        See Also
+        See also
         --------
         scipy.signal.detrend
             for details on the options for the `detrend` argument, and
@@ -1873,7 +1989,7 @@ class TimeSeries(TimeSeriesBase):
         notched : `TimeSeries`
            a notch-filtered copy of the input `TimeSeries`
 
-        See Also
+        See also
         --------
         TimeSeries.filter
            for details on the filtering method
@@ -1917,7 +2033,7 @@ class TimeSeries(TimeSeriesBase):
         qgram : `EventTable`
             a table of time-frequency tiles on the most significant `QPlane`
 
-        See Also
+        See also
         --------
         TimeSeries.q_transform
             for a method to interpolate the raw Q-transform over a regularly
@@ -2028,7 +2144,7 @@ class TimeSeries(TimeSeriesBase):
         out : `~gwpy.spectrogram.Spectrogram`
             output `Spectrogram` of normalised Q energy
 
-        See Also
+        See also
         --------
         TimeSeries.asd
             for documentation on acceptable `**asd_kw`
