@@ -27,6 +27,8 @@ from .misc import (
     gprint,
     if_not_none,
     null_context,
+    round_to_power,
+    unique,
 )
 
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
